"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import waChatLockSettings.WAProtobufsChatLockSettings_pb2
import waCommon.WACommon_pb2
import waDeviceCapabilities.WAProtobufsDeviceCapabilities_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CallLogRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _CallType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CallTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CallLogRecord._CallType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        REGULAR: CallLogRecord._CallType.ValueType  # 0
        SCHEDULED_CALL: CallLogRecord._CallType.ValueType  # 1
        VOICE_CHAT: CallLogRecord._CallType.ValueType  # 2

    class CallType(_CallType, metaclass=_CallTypeEnumTypeWrapper): ...
    REGULAR: CallLogRecord.CallType.ValueType  # 0
    SCHEDULED_CALL: CallLogRecord.CallType.ValueType  # 1
    VOICE_CHAT: CallLogRecord.CallType.ValueType  # 2

    class _SilenceReason:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SilenceReasonEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CallLogRecord._SilenceReason.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NONE: CallLogRecord._SilenceReason.ValueType  # 0
        SCHEDULED: CallLogRecord._SilenceReason.ValueType  # 1
        PRIVACY: CallLogRecord._SilenceReason.ValueType  # 2
        LIGHTWEIGHT: CallLogRecord._SilenceReason.ValueType  # 3

    class SilenceReason(_SilenceReason, metaclass=_SilenceReasonEnumTypeWrapper): ...
    NONE: CallLogRecord.SilenceReason.ValueType  # 0
    SCHEDULED: CallLogRecord.SilenceReason.ValueType  # 1
    PRIVACY: CallLogRecord.SilenceReason.ValueType  # 2
    LIGHTWEIGHT: CallLogRecord.SilenceReason.ValueType  # 3

    class _CallResult:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CallResultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CallLogRecord._CallResult.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CONNECTED: CallLogRecord._CallResult.ValueType  # 0
        REJECTED: CallLogRecord._CallResult.ValueType  # 1
        CANCELLED: CallLogRecord._CallResult.ValueType  # 2
        ACCEPTEDELSEWHERE: CallLogRecord._CallResult.ValueType  # 3
        MISSED: CallLogRecord._CallResult.ValueType  # 4
        INVALID: CallLogRecord._CallResult.ValueType  # 5
        UNAVAILABLE: CallLogRecord._CallResult.ValueType  # 6
        UPCOMING: CallLogRecord._CallResult.ValueType  # 7
        FAILED: CallLogRecord._CallResult.ValueType  # 8
        ABANDONED: CallLogRecord._CallResult.ValueType  # 9
        ONGOING: CallLogRecord._CallResult.ValueType  # 10

    class CallResult(_CallResult, metaclass=_CallResultEnumTypeWrapper): ...
    CONNECTED: CallLogRecord.CallResult.ValueType  # 0
    REJECTED: CallLogRecord.CallResult.ValueType  # 1
    CANCELLED: CallLogRecord.CallResult.ValueType  # 2
    ACCEPTEDELSEWHERE: CallLogRecord.CallResult.ValueType  # 3
    MISSED: CallLogRecord.CallResult.ValueType  # 4
    INVALID: CallLogRecord.CallResult.ValueType  # 5
    UNAVAILABLE: CallLogRecord.CallResult.ValueType  # 6
    UPCOMING: CallLogRecord.CallResult.ValueType  # 7
    FAILED: CallLogRecord.CallResult.ValueType  # 8
    ABANDONED: CallLogRecord.CallResult.ValueType  # 9
    ONGOING: CallLogRecord.CallResult.ValueType  # 10

    @typing.final
    class ParticipantInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        USERJID_FIELD_NUMBER: builtins.int
        CALLRESULT_FIELD_NUMBER: builtins.int
        userJID: builtins.str
        callResult: global___CallLogRecord.CallResult.ValueType
        def __init__(
            self,
            *,
            userJID: builtins.str | None = ...,
            callResult: global___CallLogRecord.CallResult.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["callResult", b"callResult", "userJID", b"userJID"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["callResult", b"callResult", "userJID", b"userJID"]) -> None: ...

    CALLRESULT_FIELD_NUMBER: builtins.int
    ISDNDMODE_FIELD_NUMBER: builtins.int
    SILENCEREASON_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    STARTTIME_FIELD_NUMBER: builtins.int
    ISINCOMING_FIELD_NUMBER: builtins.int
    ISVIDEO_FIELD_NUMBER: builtins.int
    ISCALLLINK_FIELD_NUMBER: builtins.int
    CALLLINKTOKEN_FIELD_NUMBER: builtins.int
    SCHEDULEDCALLID_FIELD_NUMBER: builtins.int
    CALLID_FIELD_NUMBER: builtins.int
    CALLCREATORJID_FIELD_NUMBER: builtins.int
    GROUPJID_FIELD_NUMBER: builtins.int
    PARTICIPANTS_FIELD_NUMBER: builtins.int
    CALLTYPE_FIELD_NUMBER: builtins.int
    callResult: global___CallLogRecord.CallResult.ValueType
    isDndMode: builtins.bool
    silenceReason: global___CallLogRecord.SilenceReason.ValueType
    duration: builtins.int
    startTime: builtins.int
    isIncoming: builtins.bool
    isVideo: builtins.bool
    isCallLink: builtins.bool
    callLinkToken: builtins.str
    scheduledCallID: builtins.str
    callID: builtins.str
    callCreatorJID: builtins.str
    groupJID: builtins.str
    callType: global___CallLogRecord.CallType.ValueType
    @property
    def participants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CallLogRecord.ParticipantInfo]: ...
    def __init__(
        self,
        *,
        callResult: global___CallLogRecord.CallResult.ValueType | None = ...,
        isDndMode: builtins.bool | None = ...,
        silenceReason: global___CallLogRecord.SilenceReason.ValueType | None = ...,
        duration: builtins.int | None = ...,
        startTime: builtins.int | None = ...,
        isIncoming: builtins.bool | None = ...,
        isVideo: builtins.bool | None = ...,
        isCallLink: builtins.bool | None = ...,
        callLinkToken: builtins.str | None = ...,
        scheduledCallID: builtins.str | None = ...,
        callID: builtins.str | None = ...,
        callCreatorJID: builtins.str | None = ...,
        groupJID: builtins.str | None = ...,
        participants: collections.abc.Iterable[global___CallLogRecord.ParticipantInfo] | None = ...,
        callType: global___CallLogRecord.CallType.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["callCreatorJID", b"callCreatorJID", "callID", b"callID", "callLinkToken", b"callLinkToken", "callResult", b"callResult", "callType", b"callType", "duration", b"duration", "groupJID", b"groupJID", "isCallLink", b"isCallLink", "isDndMode", b"isDndMode", "isIncoming", b"isIncoming", "isVideo", b"isVideo", "scheduledCallID", b"scheduledCallID", "silenceReason", b"silenceReason", "startTime", b"startTime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["callCreatorJID", b"callCreatorJID", "callID", b"callID", "callLinkToken", b"callLinkToken", "callResult", b"callResult", "callType", b"callType", "duration", b"duration", "groupJID", b"groupJID", "isCallLink", b"isCallLink", "isDndMode", b"isDndMode", "isIncoming", b"isIncoming", "isVideo", b"isVideo", "participants", b"participants", "scheduledCallID", b"scheduledCallID", "silenceReason", b"silenceReason", "startTime", b"startTime"]) -> None: ...

global___CallLogRecord = CallLogRecord

@typing.final
class NotificationActivitySettingAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _NotificationActivitySetting:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _NotificationActivitySettingEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[NotificationActivitySettingAction._NotificationActivitySetting.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DEFAULT_ALL_MESSAGES: NotificationActivitySettingAction._NotificationActivitySetting.ValueType  # 0
        ALL_MESSAGES: NotificationActivitySettingAction._NotificationActivitySetting.ValueType  # 1
        HIGHLIGHTS: NotificationActivitySettingAction._NotificationActivitySetting.ValueType  # 2
        DEFAULT_HIGHLIGHTS: NotificationActivitySettingAction._NotificationActivitySetting.ValueType  # 3

    class NotificationActivitySetting(_NotificationActivitySetting, metaclass=_NotificationActivitySettingEnumTypeWrapper): ...
    DEFAULT_ALL_MESSAGES: NotificationActivitySettingAction.NotificationActivitySetting.ValueType  # 0
    ALL_MESSAGES: NotificationActivitySettingAction.NotificationActivitySetting.ValueType  # 1
    HIGHLIGHTS: NotificationActivitySettingAction.NotificationActivitySetting.ValueType  # 2
    DEFAULT_HIGHLIGHTS: NotificationActivitySettingAction.NotificationActivitySetting.ValueType  # 3

    NOTIFICATIONACTIVITYSETTING_FIELD_NUMBER: builtins.int
    notificationActivitySetting: global___NotificationActivitySettingAction.NotificationActivitySetting.ValueType
    def __init__(
        self,
        *,
        notificationActivitySetting: global___NotificationActivitySettingAction.NotificationActivitySetting.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["notificationActivitySetting", b"notificationActivitySetting"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["notificationActivitySetting", b"notificationActivitySetting"]) -> None: ...

global___NotificationActivitySettingAction = NotificationActivitySettingAction

@typing.final
class WaffleAccountLinkStateAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _AccountLinkState:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AccountLinkStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[WaffleAccountLinkStateAction._AccountLinkState.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ACTIVE: WaffleAccountLinkStateAction._AccountLinkState.ValueType  # 0

    class AccountLinkState(_AccountLinkState, metaclass=_AccountLinkStateEnumTypeWrapper): ...
    ACTIVE: WaffleAccountLinkStateAction.AccountLinkState.ValueType  # 0

    LINKSTATE_FIELD_NUMBER: builtins.int
    linkState: global___WaffleAccountLinkStateAction.AccountLinkState.ValueType
    def __init__(
        self,
        *,
        linkState: global___WaffleAccountLinkStateAction.AccountLinkState.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["linkState", b"linkState"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["linkState", b"linkState"]) -> None: ...

global___WaffleAccountLinkStateAction = WaffleAccountLinkStateAction

@typing.final
class MerchantPaymentPartnerAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MerchantPaymentPartnerAction._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ACTIVE: MerchantPaymentPartnerAction._Status.ValueType  # 0
        INACTIVE: MerchantPaymentPartnerAction._Status.ValueType  # 1

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    ACTIVE: MerchantPaymentPartnerAction.Status.ValueType  # 0
    INACTIVE: MerchantPaymentPartnerAction.Status.ValueType  # 1

    STATUS_FIELD_NUMBER: builtins.int
    COUNTRY_FIELD_NUMBER: builtins.int
    GATEWAYNAME_FIELD_NUMBER: builtins.int
    CREDENTIALID_FIELD_NUMBER: builtins.int
    status: global___MerchantPaymentPartnerAction.Status.ValueType
    country: builtins.str
    gatewayName: builtins.str
    credentialID: builtins.str
    def __init__(
        self,
        *,
        status: global___MerchantPaymentPartnerAction.Status.ValueType | None = ...,
        country: builtins.str | None = ...,
        gatewayName: builtins.str | None = ...,
        credentialID: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["country", b"country", "credentialID", b"credentialID", "gatewayName", b"gatewayName", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["country", b"country", "credentialID", b"credentialID", "gatewayName", b"gatewayName", "status", b"status"]) -> None: ...

global___MerchantPaymentPartnerAction = MerchantPaymentPartnerAction

@typing.final
class NoteEditAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _NoteType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _NoteTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[NoteEditAction._NoteType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNSTRUCTURED: NoteEditAction._NoteType.ValueType  # 1
        STRUCTURED: NoteEditAction._NoteType.ValueType  # 2

    class NoteType(_NoteType, metaclass=_NoteTypeEnumTypeWrapper): ...
    UNSTRUCTURED: NoteEditAction.NoteType.ValueType  # 1
    STRUCTURED: NoteEditAction.NoteType.ValueType  # 2

    TYPE_FIELD_NUMBER: builtins.int
    CHATJID_FIELD_NUMBER: builtins.int
    CREATEDAT_FIELD_NUMBER: builtins.int
    DELETED_FIELD_NUMBER: builtins.int
    UNSTRUCTUREDCONTENT_FIELD_NUMBER: builtins.int
    type: global___NoteEditAction.NoteType.ValueType
    chatJID: builtins.str
    createdAt: builtins.int
    deleted: builtins.bool
    unstructuredContent: builtins.str
    def __init__(
        self,
        *,
        type: global___NoteEditAction.NoteType.ValueType | None = ...,
        chatJID: builtins.str | None = ...,
        createdAt: builtins.int | None = ...,
        deleted: builtins.bool | None = ...,
        unstructuredContent: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["chatJID", b"chatJID", "createdAt", b"createdAt", "deleted", b"deleted", "type", b"type", "unstructuredContent", b"unstructuredContent"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chatJID", b"chatJID", "createdAt", b"createdAt", "deleted", b"deleted", "type", b"type", "unstructuredContent", b"unstructuredContent"]) -> None: ...

global___NoteEditAction = NoteEditAction

@typing.final
class StatusPrivacyAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _StatusDistributionMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusDistributionModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[StatusPrivacyAction._StatusDistributionMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ALLOW_LIST: StatusPrivacyAction._StatusDistributionMode.ValueType  # 0
        DENY_LIST: StatusPrivacyAction._StatusDistributionMode.ValueType  # 1
        CONTACTS: StatusPrivacyAction._StatusDistributionMode.ValueType  # 2

    class StatusDistributionMode(_StatusDistributionMode, metaclass=_StatusDistributionModeEnumTypeWrapper): ...
    ALLOW_LIST: StatusPrivacyAction.StatusDistributionMode.ValueType  # 0
    DENY_LIST: StatusPrivacyAction.StatusDistributionMode.ValueType  # 1
    CONTACTS: StatusPrivacyAction.StatusDistributionMode.ValueType  # 2

    MODE_FIELD_NUMBER: builtins.int
    USERJID_FIELD_NUMBER: builtins.int
    mode: global___StatusPrivacyAction.StatusDistributionMode.ValueType
    @property
    def userJID(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        mode: global___StatusPrivacyAction.StatusDistributionMode.ValueType | None = ...,
        userJID: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["mode", b"mode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["mode", b"mode", "userJID", b"userJID"]) -> None: ...

global___StatusPrivacyAction = StatusPrivacyAction

@typing.final
class MarketingMessageAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _MarketingMessagePrototypeType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _MarketingMessagePrototypeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MarketingMessageAction._MarketingMessagePrototypeType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PERSONALIZED: MarketingMessageAction._MarketingMessagePrototypeType.ValueType  # 0

    class MarketingMessagePrototypeType(_MarketingMessagePrototypeType, metaclass=_MarketingMessagePrototypeTypeEnumTypeWrapper): ...
    PERSONALIZED: MarketingMessageAction.MarketingMessagePrototypeType.ValueType  # 0

    NAME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CREATEDAT_FIELD_NUMBER: builtins.int
    LASTSENTAT_FIELD_NUMBER: builtins.int
    ISDELETED_FIELD_NUMBER: builtins.int
    MEDIAID_FIELD_NUMBER: builtins.int
    name: builtins.str
    message: builtins.str
    type: global___MarketingMessageAction.MarketingMessagePrototypeType.ValueType
    createdAt: builtins.int
    lastSentAt: builtins.int
    isDeleted: builtins.bool
    mediaID: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
        message: builtins.str | None = ...,
        type: global___MarketingMessageAction.MarketingMessagePrototypeType.ValueType | None = ...,
        createdAt: builtins.int | None = ...,
        lastSentAt: builtins.int | None = ...,
        isDeleted: builtins.bool | None = ...,
        mediaID: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["createdAt", b"createdAt", "isDeleted", b"isDeleted", "lastSentAt", b"lastSentAt", "mediaID", b"mediaID", "message", b"message", "name", b"name", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["createdAt", b"createdAt", "isDeleted", b"isDeleted", "lastSentAt", b"lastSentAt", "mediaID", b"mediaID", "message", b"message", "name", b"name", "type", b"type"]) -> None: ...

global___MarketingMessageAction = MarketingMessageAction

@typing.final
class UsernameChatStartModeAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ChatStartMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ChatStartModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UsernameChatStartModeAction._ChatStartMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LID: UsernameChatStartModeAction._ChatStartMode.ValueType  # 1
        PN: UsernameChatStartModeAction._ChatStartMode.ValueType  # 2

    class ChatStartMode(_ChatStartMode, metaclass=_ChatStartModeEnumTypeWrapper): ...
    LID: UsernameChatStartModeAction.ChatStartMode.ValueType  # 1
    PN: UsernameChatStartModeAction.ChatStartMode.ValueType  # 2

    CHATSTARTMODE_FIELD_NUMBER: builtins.int
    chatStartMode: global___UsernameChatStartModeAction.ChatStartMode.ValueType
    def __init__(
        self,
        *,
        chatStartMode: global___UsernameChatStartModeAction.ChatStartMode.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["chatStartMode", b"chatStartMode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chatStartMode", b"chatStartMode"]) -> None: ...

global___UsernameChatStartModeAction = UsernameChatStartModeAction

@typing.final
class LabelEditAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ListType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ListTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[LabelEditAction._ListType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NONE: LabelEditAction._ListType.ValueType  # 0
        UNREAD: LabelEditAction._ListType.ValueType  # 1
        GROUPS: LabelEditAction._ListType.ValueType  # 2
        FAVORITES: LabelEditAction._ListType.ValueType  # 3
        PREDEFINED: LabelEditAction._ListType.ValueType  # 4
        CUSTOM: LabelEditAction._ListType.ValueType  # 5
        COMMUNITY: LabelEditAction._ListType.ValueType  # 6
        SERVER_ASSIGNED: LabelEditAction._ListType.ValueType  # 7

    class ListType(_ListType, metaclass=_ListTypeEnumTypeWrapper): ...
    NONE: LabelEditAction.ListType.ValueType  # 0
    UNREAD: LabelEditAction.ListType.ValueType  # 1
    GROUPS: LabelEditAction.ListType.ValueType  # 2
    FAVORITES: LabelEditAction.ListType.ValueType  # 3
    PREDEFINED: LabelEditAction.ListType.ValueType  # 4
    CUSTOM: LabelEditAction.ListType.ValueType  # 5
    COMMUNITY: LabelEditAction.ListType.ValueType  # 6
    SERVER_ASSIGNED: LabelEditAction.ListType.ValueType  # 7

    NAME_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    PREDEFINEDID_FIELD_NUMBER: builtins.int
    DELETED_FIELD_NUMBER: builtins.int
    ORDERINDEX_FIELD_NUMBER: builtins.int
    ISACTIVE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ISIMMUTABLE_FIELD_NUMBER: builtins.int
    name: builtins.str
    color: builtins.int
    predefinedID: builtins.int
    deleted: builtins.bool
    orderIndex: builtins.int
    isActive: builtins.bool
    type: global___LabelEditAction.ListType.ValueType
    isImmutable: builtins.bool
    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
        color: builtins.int | None = ...,
        predefinedID: builtins.int | None = ...,
        deleted: builtins.bool | None = ...,
        orderIndex: builtins.int | None = ...,
        isActive: builtins.bool | None = ...,
        type: global___LabelEditAction.ListType.ValueType | None = ...,
        isImmutable: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["color", b"color", "deleted", b"deleted", "isActive", b"isActive", "isImmutable", b"isImmutable", "name", b"name", "orderIndex", b"orderIndex", "predefinedID", b"predefinedID", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["color", b"color", "deleted", b"deleted", "isActive", b"isActive", "isImmutable", b"isImmutable", "name", b"name", "orderIndex", b"orderIndex", "predefinedID", b"predefinedID", "type", b"type"]) -> None: ...

global___LabelEditAction = LabelEditAction

@typing.final
class PatchDebugData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Platform:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PlatformEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PatchDebugData._Platform.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ANDROID: PatchDebugData._Platform.ValueType  # 0
        SMBA: PatchDebugData._Platform.ValueType  # 1
        IPHONE: PatchDebugData._Platform.ValueType  # 2
        SMBI: PatchDebugData._Platform.ValueType  # 3
        WEB: PatchDebugData._Platform.ValueType  # 4
        UWP: PatchDebugData._Platform.ValueType  # 5
        DARWIN: PatchDebugData._Platform.ValueType  # 6
        IPAD: PatchDebugData._Platform.ValueType  # 7
        WEAROS: PatchDebugData._Platform.ValueType  # 8

    class Platform(_Platform, metaclass=_PlatformEnumTypeWrapper): ...
    ANDROID: PatchDebugData.Platform.ValueType  # 0
    SMBA: PatchDebugData.Platform.ValueType  # 1
    IPHONE: PatchDebugData.Platform.ValueType  # 2
    SMBI: PatchDebugData.Platform.ValueType  # 3
    WEB: PatchDebugData.Platform.ValueType  # 4
    UWP: PatchDebugData.Platform.ValueType  # 5
    DARWIN: PatchDebugData.Platform.ValueType  # 6
    IPAD: PatchDebugData.Platform.ValueType  # 7
    WEAROS: PatchDebugData.Platform.ValueType  # 8

    CURRENTLTHASH_FIELD_NUMBER: builtins.int
    NEWLTHASH_FIELD_NUMBER: builtins.int
    PATCHVERSION_FIELD_NUMBER: builtins.int
    COLLECTIONNAME_FIELD_NUMBER: builtins.int
    FIRSTFOURBYTESFROMAHASHOFSNAPSHOTMACKEY_FIELD_NUMBER: builtins.int
    NEWLTHASHSUBTRACT_FIELD_NUMBER: builtins.int
    NUMBERADD_FIELD_NUMBER: builtins.int
    NUMBERREMOVE_FIELD_NUMBER: builtins.int
    NUMBEROVERRIDE_FIELD_NUMBER: builtins.int
    SENDERPLATFORM_FIELD_NUMBER: builtins.int
    ISSENDERPRIMARY_FIELD_NUMBER: builtins.int
    currentLthash: builtins.bytes
    newLthash: builtins.bytes
    patchVersion: builtins.bytes
    collectionName: builtins.bytes
    firstFourBytesFromAHashOfSnapshotMACKey: builtins.bytes
    newLthashSubtract: builtins.bytes
    numberAdd: builtins.int
    numberRemove: builtins.int
    numberOverride: builtins.int
    senderPlatform: global___PatchDebugData.Platform.ValueType
    isSenderPrimary: builtins.bool
    def __init__(
        self,
        *,
        currentLthash: builtins.bytes | None = ...,
        newLthash: builtins.bytes | None = ...,
        patchVersion: builtins.bytes | None = ...,
        collectionName: builtins.bytes | None = ...,
        firstFourBytesFromAHashOfSnapshotMACKey: builtins.bytes | None = ...,
        newLthashSubtract: builtins.bytes | None = ...,
        numberAdd: builtins.int | None = ...,
        numberRemove: builtins.int | None = ...,
        numberOverride: builtins.int | None = ...,
        senderPlatform: global___PatchDebugData.Platform.ValueType | None = ...,
        isSenderPrimary: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["collectionName", b"collectionName", "currentLthash", b"currentLthash", "firstFourBytesFromAHashOfSnapshotMACKey", b"firstFourBytesFromAHashOfSnapshotMACKey", "isSenderPrimary", b"isSenderPrimary", "newLthash", b"newLthash", "newLthashSubtract", b"newLthashSubtract", "numberAdd", b"numberAdd", "numberOverride", b"numberOverride", "numberRemove", b"numberRemove", "patchVersion", b"patchVersion", "senderPlatform", b"senderPlatform"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["collectionName", b"collectionName", "currentLthash", b"currentLthash", "firstFourBytesFromAHashOfSnapshotMACKey", b"firstFourBytesFromAHashOfSnapshotMACKey", "isSenderPrimary", b"isSenderPrimary", "newLthash", b"newLthash", "newLthashSubtract", b"newLthashSubtract", "numberAdd", b"numberAdd", "numberOverride", b"numberOverride", "numberRemove", b"numberRemove", "patchVersion", b"patchVersion", "senderPlatform", b"senderPlatform"]) -> None: ...

global___PatchDebugData = PatchDebugData

@typing.final
class RecentEmojiWeight(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMOJI_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    emoji: builtins.str
    weight: builtins.float
    def __init__(
        self,
        *,
        emoji: builtins.str | None = ...,
        weight: builtins.float | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["emoji", b"emoji", "weight", b"weight"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["emoji", b"emoji", "weight", b"weight"]) -> None: ...

global___RecentEmojiWeight = RecentEmojiWeight

@typing.final
class SyncActionValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    STARACTION_FIELD_NUMBER: builtins.int
    CONTACTACTION_FIELD_NUMBER: builtins.int
    MUTEACTION_FIELD_NUMBER: builtins.int
    PINACTION_FIELD_NUMBER: builtins.int
    SECURITYNOTIFICATIONSETTING_FIELD_NUMBER: builtins.int
    PUSHNAMESETTING_FIELD_NUMBER: builtins.int
    QUICKREPLYACTION_FIELD_NUMBER: builtins.int
    RECENTEMOJIWEIGHTSACTION_FIELD_NUMBER: builtins.int
    LABELEDITACTION_FIELD_NUMBER: builtins.int
    LABELASSOCIATIONACTION_FIELD_NUMBER: builtins.int
    LOCALESETTING_FIELD_NUMBER: builtins.int
    ARCHIVECHATACTION_FIELD_NUMBER: builtins.int
    DELETEMESSAGEFORMEACTION_FIELD_NUMBER: builtins.int
    KEYEXPIRATION_FIELD_NUMBER: builtins.int
    MARKCHATASREADACTION_FIELD_NUMBER: builtins.int
    CLEARCHATACTION_FIELD_NUMBER: builtins.int
    DELETECHATACTION_FIELD_NUMBER: builtins.int
    UNARCHIVECHATSSETTING_FIELD_NUMBER: builtins.int
    PRIMARYFEATURE_FIELD_NUMBER: builtins.int
    ANDROIDUNSUPPORTEDACTIONS_FIELD_NUMBER: builtins.int
    AGENTACTION_FIELD_NUMBER: builtins.int
    SUBSCRIPTIONACTION_FIELD_NUMBER: builtins.int
    USERSTATUSMUTEACTION_FIELD_NUMBER: builtins.int
    TIMEFORMATACTION_FIELD_NUMBER: builtins.int
    NUXACTION_FIELD_NUMBER: builtins.int
    PRIMARYVERSIONACTION_FIELD_NUMBER: builtins.int
    STICKERACTION_FIELD_NUMBER: builtins.int
    REMOVERECENTSTICKERACTION_FIELD_NUMBER: builtins.int
    CHATASSIGNMENT_FIELD_NUMBER: builtins.int
    CHATASSIGNMENTOPENEDSTATUS_FIELD_NUMBER: builtins.int
    PNFORLIDCHATACTION_FIELD_NUMBER: builtins.int
    MARKETINGMESSAGEACTION_FIELD_NUMBER: builtins.int
    MARKETINGMESSAGEBROADCASTACTION_FIELD_NUMBER: builtins.int
    EXTERNALWEBBETAACTION_FIELD_NUMBER: builtins.int
    PRIVACYSETTINGRELAYALLCALLS_FIELD_NUMBER: builtins.int
    CALLLOGACTION_FIELD_NUMBER: builtins.int
    STATUSPRIVACY_FIELD_NUMBER: builtins.int
    BOTWELCOMEREQUESTACTION_FIELD_NUMBER: builtins.int
    DELETEINDIVIDUALCALLLOG_FIELD_NUMBER: builtins.int
    LABELREORDERINGACTION_FIELD_NUMBER: builtins.int
    PAYMENTINFOACTION_FIELD_NUMBER: builtins.int
    CUSTOMPAYMENTMETHODSACTION_FIELD_NUMBER: builtins.int
    LOCKCHATACTION_FIELD_NUMBER: builtins.int
    CHATLOCKSETTINGS_FIELD_NUMBER: builtins.int
    WAMOUSERIDENTIFIERACTION_FIELD_NUMBER: builtins.int
    PRIVACYSETTINGDISABLELINKPREVIEWSACTION_FIELD_NUMBER: builtins.int
    DEVICECAPABILITIES_FIELD_NUMBER: builtins.int
    NOTEEDITACTION_FIELD_NUMBER: builtins.int
    FAVORITESACTION_FIELD_NUMBER: builtins.int
    MERCHANTPAYMENTPARTNERACTION_FIELD_NUMBER: builtins.int
    WAFFLEACCOUNTLINKSTATEACTION_FIELD_NUMBER: builtins.int
    USERNAMECHATSTARTMODE_FIELD_NUMBER: builtins.int
    NOTIFICATIONACTIVITYSETTINGACTION_FIELD_NUMBER: builtins.int
    LIDCONTACTACTION_FIELD_NUMBER: builtins.int
    CTWAPERCUSTOMERDATASHARINGACTION_FIELD_NUMBER: builtins.int
    timestamp: builtins.int
    @property
    def starAction(self) -> global___StarAction: ...
    @property
    def contactAction(self) -> global___ContactAction: ...
    @property
    def muteAction(self) -> global___MuteAction: ...
    @property
    def pinAction(self) -> global___PinAction: ...
    @property
    def securityNotificationSetting(self) -> global___SecurityNotificationSetting: ...
    @property
    def pushNameSetting(self) -> global___PushNameSetting: ...
    @property
    def quickReplyAction(self) -> global___QuickReplyAction: ...
    @property
    def recentEmojiWeightsAction(self) -> global___RecentEmojiWeightsAction: ...
    @property
    def labelEditAction(self) -> global___LabelEditAction: ...
    @property
    def labelAssociationAction(self) -> global___LabelAssociationAction: ...
    @property
    def localeSetting(self) -> global___LocaleSetting: ...
    @property
    def archiveChatAction(self) -> global___ArchiveChatAction: ...
    @property
    def deleteMessageForMeAction(self) -> global___DeleteMessageForMeAction: ...
    @property
    def keyExpiration(self) -> global___KeyExpiration: ...
    @property
    def markChatAsReadAction(self) -> global___MarkChatAsReadAction: ...
    @property
    def clearChatAction(self) -> global___ClearChatAction: ...
    @property
    def deleteChatAction(self) -> global___DeleteChatAction: ...
    @property
    def unarchiveChatsSetting(self) -> global___UnarchiveChatsSetting: ...
    @property
    def primaryFeature(self) -> global___PrimaryFeature: ...
    @property
    def androidUnsupportedActions(self) -> global___AndroidUnsupportedActions: ...
    @property
    def agentAction(self) -> global___AgentAction: ...
    @property
    def subscriptionAction(self) -> global___SubscriptionAction: ...
    @property
    def userStatusMuteAction(self) -> global___UserStatusMuteAction: ...
    @property
    def timeFormatAction(self) -> global___TimeFormatAction: ...
    @property
    def nuxAction(self) -> global___NuxAction: ...
    @property
    def primaryVersionAction(self) -> global___PrimaryVersionAction: ...
    @property
    def stickerAction(self) -> global___StickerAction: ...
    @property
    def removeRecentStickerAction(self) -> global___RemoveRecentStickerAction: ...
    @property
    def chatAssignment(self) -> global___ChatAssignmentAction: ...
    @property
    def chatAssignmentOpenedStatus(self) -> global___ChatAssignmentOpenedStatusAction: ...
    @property
    def pnForLidChatAction(self) -> global___PnForLidChatAction: ...
    @property
    def marketingMessageAction(self) -> global___MarketingMessageAction: ...
    @property
    def marketingMessageBroadcastAction(self) -> global___MarketingMessageBroadcastAction: ...
    @property
    def externalWebBetaAction(self) -> global___ExternalWebBetaAction: ...
    @property
    def privacySettingRelayAllCalls(self) -> global___PrivacySettingRelayAllCalls: ...
    @property
    def callLogAction(self) -> global___CallLogAction: ...
    @property
    def statusPrivacy(self) -> global___StatusPrivacyAction: ...
    @property
    def botWelcomeRequestAction(self) -> global___BotWelcomeRequestAction: ...
    @property
    def deleteIndividualCallLog(self) -> global___DeleteIndividualCallLogAction: ...
    @property
    def labelReorderingAction(self) -> global___LabelReorderingAction: ...
    @property
    def paymentInfoAction(self) -> global___PaymentInfoAction: ...
    @property
    def customPaymentMethodsAction(self) -> global___CustomPaymentMethodsAction: ...
    @property
    def lockChatAction(self) -> global___LockChatAction: ...
    @property
    def chatLockSettings(self) -> waChatLockSettings.WAProtobufsChatLockSettings_pb2.ChatLockSettings: ...
    @property
    def wamoUserIdentifierAction(self) -> global___WamoUserIdentifierAction: ...
    @property
    def privacySettingDisableLinkPreviewsAction(self) -> global___PrivacySettingDisableLinkPreviewsAction: ...
    @property
    def deviceCapabilities(self) -> waDeviceCapabilities.WAProtobufsDeviceCapabilities_pb2.DeviceCapabilities: ...
    @property
    def noteEditAction(self) -> global___NoteEditAction: ...
    @property
    def favoritesAction(self) -> global___FavoritesAction: ...
    @property
    def merchantPaymentPartnerAction(self) -> global___MerchantPaymentPartnerAction: ...
    @property
    def waffleAccountLinkStateAction(self) -> global___WaffleAccountLinkStateAction: ...
    @property
    def usernameChatStartMode(self) -> global___UsernameChatStartModeAction: ...
    @property
    def notificationActivitySettingAction(self) -> global___NotificationActivitySettingAction: ...
    @property
    def lidContactAction(self) -> global___LidContactAction: ...
    @property
    def ctwaPerCustomerDataSharingAction(self) -> global___CtwaPerCustomerDataSharingAction: ...
    def __init__(
        self,
        *,
        timestamp: builtins.int | None = ...,
        starAction: global___StarAction | None = ...,
        contactAction: global___ContactAction | None = ...,
        muteAction: global___MuteAction | None = ...,
        pinAction: global___PinAction | None = ...,
        securityNotificationSetting: global___SecurityNotificationSetting | None = ...,
        pushNameSetting: global___PushNameSetting | None = ...,
        quickReplyAction: global___QuickReplyAction | None = ...,
        recentEmojiWeightsAction: global___RecentEmojiWeightsAction | None = ...,
        labelEditAction: global___LabelEditAction | None = ...,
        labelAssociationAction: global___LabelAssociationAction | None = ...,
        localeSetting: global___LocaleSetting | None = ...,
        archiveChatAction: global___ArchiveChatAction | None = ...,
        deleteMessageForMeAction: global___DeleteMessageForMeAction | None = ...,
        keyExpiration: global___KeyExpiration | None = ...,
        markChatAsReadAction: global___MarkChatAsReadAction | None = ...,
        clearChatAction: global___ClearChatAction | None = ...,
        deleteChatAction: global___DeleteChatAction | None = ...,
        unarchiveChatsSetting: global___UnarchiveChatsSetting | None = ...,
        primaryFeature: global___PrimaryFeature | None = ...,
        androidUnsupportedActions: global___AndroidUnsupportedActions | None = ...,
        agentAction: global___AgentAction | None = ...,
        subscriptionAction: global___SubscriptionAction | None = ...,
        userStatusMuteAction: global___UserStatusMuteAction | None = ...,
        timeFormatAction: global___TimeFormatAction | None = ...,
        nuxAction: global___NuxAction | None = ...,
        primaryVersionAction: global___PrimaryVersionAction | None = ...,
        stickerAction: global___StickerAction | None = ...,
        removeRecentStickerAction: global___RemoveRecentStickerAction | None = ...,
        chatAssignment: global___ChatAssignmentAction | None = ...,
        chatAssignmentOpenedStatus: global___ChatAssignmentOpenedStatusAction | None = ...,
        pnForLidChatAction: global___PnForLidChatAction | None = ...,
        marketingMessageAction: global___MarketingMessageAction | None = ...,
        marketingMessageBroadcastAction: global___MarketingMessageBroadcastAction | None = ...,
        externalWebBetaAction: global___ExternalWebBetaAction | None = ...,
        privacySettingRelayAllCalls: global___PrivacySettingRelayAllCalls | None = ...,
        callLogAction: global___CallLogAction | None = ...,
        statusPrivacy: global___StatusPrivacyAction | None = ...,
        botWelcomeRequestAction: global___BotWelcomeRequestAction | None = ...,
        deleteIndividualCallLog: global___DeleteIndividualCallLogAction | None = ...,
        labelReorderingAction: global___LabelReorderingAction | None = ...,
        paymentInfoAction: global___PaymentInfoAction | None = ...,
        customPaymentMethodsAction: global___CustomPaymentMethodsAction | None = ...,
        lockChatAction: global___LockChatAction | None = ...,
        chatLockSettings: waChatLockSettings.WAProtobufsChatLockSettings_pb2.ChatLockSettings | None = ...,
        wamoUserIdentifierAction: global___WamoUserIdentifierAction | None = ...,
        privacySettingDisableLinkPreviewsAction: global___PrivacySettingDisableLinkPreviewsAction | None = ...,
        deviceCapabilities: waDeviceCapabilities.WAProtobufsDeviceCapabilities_pb2.DeviceCapabilities | None = ...,
        noteEditAction: global___NoteEditAction | None = ...,
        favoritesAction: global___FavoritesAction | None = ...,
        merchantPaymentPartnerAction: global___MerchantPaymentPartnerAction | None = ...,
        waffleAccountLinkStateAction: global___WaffleAccountLinkStateAction | None = ...,
        usernameChatStartMode: global___UsernameChatStartModeAction | None = ...,
        notificationActivitySettingAction: global___NotificationActivitySettingAction | None = ...,
        lidContactAction: global___LidContactAction | None = ...,
        ctwaPerCustomerDataSharingAction: global___CtwaPerCustomerDataSharingAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["agentAction", b"agentAction", "androidUnsupportedActions", b"androidUnsupportedActions", "archiveChatAction", b"archiveChatAction", "botWelcomeRequestAction", b"botWelcomeRequestAction", "callLogAction", b"callLogAction", "chatAssignment", b"chatAssignment", "chatAssignmentOpenedStatus", b"chatAssignmentOpenedStatus", "chatLockSettings", b"chatLockSettings", "clearChatAction", b"clearChatAction", "contactAction", b"contactAction", "ctwaPerCustomerDataSharingAction", b"ctwaPerCustomerDataSharingAction", "customPaymentMethodsAction", b"customPaymentMethodsAction", "deleteChatAction", b"deleteChatAction", "deleteIndividualCallLog", b"deleteIndividualCallLog", "deleteMessageForMeAction", b"deleteMessageForMeAction", "deviceCapabilities", b"deviceCapabilities", "externalWebBetaAction", b"externalWebBetaAction", "favoritesAction", b"favoritesAction", "keyExpiration", b"keyExpiration", "labelAssociationAction", b"labelAssociationAction", "labelEditAction", b"labelEditAction", "labelReorderingAction", b"labelReorderingAction", "lidContactAction", b"lidContactAction", "localeSetting", b"localeSetting", "lockChatAction", b"lockChatAction", "markChatAsReadAction", b"markChatAsReadAction", "marketingMessageAction", b"marketingMessageAction", "marketingMessageBroadcastAction", b"marketingMessageBroadcastAction", "merchantPaymentPartnerAction", b"merchantPaymentPartnerAction", "muteAction", b"muteAction", "noteEditAction", b"noteEditAction", "notificationActivitySettingAction", b"notificationActivitySettingAction", "nuxAction", b"nuxAction", "paymentInfoAction", b"paymentInfoAction", "pinAction", b"pinAction", "pnForLidChatAction", b"pnForLidChatAction", "primaryFeature", b"primaryFeature", "primaryVersionAction", b"primaryVersionAction", "privacySettingDisableLinkPreviewsAction", b"privacySettingDisableLinkPreviewsAction", "privacySettingRelayAllCalls", b"privacySettingRelayAllCalls", "pushNameSetting", b"pushNameSetting", "quickReplyAction", b"quickReplyAction", "recentEmojiWeightsAction", b"recentEmojiWeightsAction", "removeRecentStickerAction", b"removeRecentStickerAction", "securityNotificationSetting", b"securityNotificationSetting", "starAction", b"starAction", "statusPrivacy", b"statusPrivacy", "stickerAction", b"stickerAction", "subscriptionAction", b"subscriptionAction", "timeFormatAction", b"timeFormatAction", "timestamp", b"timestamp", "unarchiveChatsSetting", b"unarchiveChatsSetting", "userStatusMuteAction", b"userStatusMuteAction", "usernameChatStartMode", b"usernameChatStartMode", "waffleAccountLinkStateAction", b"waffleAccountLinkStateAction", "wamoUserIdentifierAction", b"wamoUserIdentifierAction"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["agentAction", b"agentAction", "androidUnsupportedActions", b"androidUnsupportedActions", "archiveChatAction", b"archiveChatAction", "botWelcomeRequestAction", b"botWelcomeRequestAction", "callLogAction", b"callLogAction", "chatAssignment", b"chatAssignment", "chatAssignmentOpenedStatus", b"chatAssignmentOpenedStatus", "chatLockSettings", b"chatLockSettings", "clearChatAction", b"clearChatAction", "contactAction", b"contactAction", "ctwaPerCustomerDataSharingAction", b"ctwaPerCustomerDataSharingAction", "customPaymentMethodsAction", b"customPaymentMethodsAction", "deleteChatAction", b"deleteChatAction", "deleteIndividualCallLog", b"deleteIndividualCallLog", "deleteMessageForMeAction", b"deleteMessageForMeAction", "deviceCapabilities", b"deviceCapabilities", "externalWebBetaAction", b"externalWebBetaAction", "favoritesAction", b"favoritesAction", "keyExpiration", b"keyExpiration", "labelAssociationAction", b"labelAssociationAction", "labelEditAction", b"labelEditAction", "labelReorderingAction", b"labelReorderingAction", "lidContactAction", b"lidContactAction", "localeSetting", b"localeSetting", "lockChatAction", b"lockChatAction", "markChatAsReadAction", b"markChatAsReadAction", "marketingMessageAction", b"marketingMessageAction", "marketingMessageBroadcastAction", b"marketingMessageBroadcastAction", "merchantPaymentPartnerAction", b"merchantPaymentPartnerAction", "muteAction", b"muteAction", "noteEditAction", b"noteEditAction", "notificationActivitySettingAction", b"notificationActivitySettingAction", "nuxAction", b"nuxAction", "paymentInfoAction", b"paymentInfoAction", "pinAction", b"pinAction", "pnForLidChatAction", b"pnForLidChatAction", "primaryFeature", b"primaryFeature", "primaryVersionAction", b"primaryVersionAction", "privacySettingDisableLinkPreviewsAction", b"privacySettingDisableLinkPreviewsAction", "privacySettingRelayAllCalls", b"privacySettingRelayAllCalls", "pushNameSetting", b"pushNameSetting", "quickReplyAction", b"quickReplyAction", "recentEmojiWeightsAction", b"recentEmojiWeightsAction", "removeRecentStickerAction", b"removeRecentStickerAction", "securityNotificationSetting", b"securityNotificationSetting", "starAction", b"starAction", "statusPrivacy", b"statusPrivacy", "stickerAction", b"stickerAction", "subscriptionAction", b"subscriptionAction", "timeFormatAction", b"timeFormatAction", "timestamp", b"timestamp", "unarchiveChatsSetting", b"unarchiveChatsSetting", "userStatusMuteAction", b"userStatusMuteAction", "usernameChatStartMode", b"usernameChatStartMode", "waffleAccountLinkStateAction", b"waffleAccountLinkStateAction", "wamoUserIdentifierAction", b"wamoUserIdentifierAction"]) -> None: ...

global___SyncActionValue = SyncActionValue

@typing.final
class CtwaPerCustomerDataSharingAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISCTWAPERCUSTOMERDATASHARINGENABLED_FIELD_NUMBER: builtins.int
    isCtwaPerCustomerDataSharingEnabled: builtins.bool
    def __init__(
        self,
        *,
        isCtwaPerCustomerDataSharingEnabled: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["isCtwaPerCustomerDataSharingEnabled", b"isCtwaPerCustomerDataSharingEnabled"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["isCtwaPerCustomerDataSharingEnabled", b"isCtwaPerCustomerDataSharingEnabled"]) -> None: ...

global___CtwaPerCustomerDataSharingAction = CtwaPerCustomerDataSharingAction

@typing.final
class LidContactAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FULLNAME_FIELD_NUMBER: builtins.int
    FIRSTNAME_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    SAVEONPRIMARYADDRESSBOOK_FIELD_NUMBER: builtins.int
    fullName: builtins.str
    firstName: builtins.str
    username: builtins.str
    saveOnPrimaryAddressbook: builtins.bool
    def __init__(
        self,
        *,
        fullName: builtins.str | None = ...,
        firstName: builtins.str | None = ...,
        username: builtins.str | None = ...,
        saveOnPrimaryAddressbook: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["firstName", b"firstName", "fullName", b"fullName", "saveOnPrimaryAddressbook", b"saveOnPrimaryAddressbook", "username", b"username"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["firstName", b"firstName", "fullName", b"fullName", "saveOnPrimaryAddressbook", b"saveOnPrimaryAddressbook", "username", b"username"]) -> None: ...

global___LidContactAction = LidContactAction

@typing.final
class FavoritesAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Favorite(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        ID: builtins.str
        def __init__(
            self,
            *,
            ID: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["ID", b"ID"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["ID", b"ID"]) -> None: ...

    FAVORITES_FIELD_NUMBER: builtins.int
    @property
    def favorites(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FavoritesAction.Favorite]: ...
    def __init__(
        self,
        *,
        favorites: collections.abc.Iterable[global___FavoritesAction.Favorite] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["favorites", b"favorites"]) -> None: ...

global___FavoritesAction = FavoritesAction

@typing.final
class PrivacySettingDisableLinkPreviewsAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISPREVIEWSDISABLED_FIELD_NUMBER: builtins.int
    isPreviewsDisabled: builtins.bool
    def __init__(
        self,
        *,
        isPreviewsDisabled: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["isPreviewsDisabled", b"isPreviewsDisabled"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["isPreviewsDisabled", b"isPreviewsDisabled"]) -> None: ...

global___PrivacySettingDisableLinkPreviewsAction = PrivacySettingDisableLinkPreviewsAction

@typing.final
class WamoUserIdentifierAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    identifier: builtins.str
    def __init__(
        self,
        *,
        identifier: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["identifier", b"identifier"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["identifier", b"identifier"]) -> None: ...

global___WamoUserIdentifierAction = WamoUserIdentifierAction

@typing.final
class LockChatAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCKED_FIELD_NUMBER: builtins.int
    locked: builtins.bool
    def __init__(
        self,
        *,
        locked: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["locked", b"locked"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["locked", b"locked"]) -> None: ...

global___LockChatAction = LockChatAction

@typing.final
class CustomPaymentMethodsAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUSTOMPAYMENTMETHODS_FIELD_NUMBER: builtins.int
    @property
    def customPaymentMethods(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomPaymentMethod]: ...
    def __init__(
        self,
        *,
        customPaymentMethods: collections.abc.Iterable[global___CustomPaymentMethod] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["customPaymentMethods", b"customPaymentMethods"]) -> None: ...

global___CustomPaymentMethodsAction = CustomPaymentMethodsAction

@typing.final
class CustomPaymentMethod(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREDENTIALID_FIELD_NUMBER: builtins.int
    COUNTRY_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    credentialID: builtins.str
    country: builtins.str
    type: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomPaymentMethodMetadata]: ...
    def __init__(
        self,
        *,
        credentialID: builtins.str | None = ...,
        country: builtins.str | None = ...,
        type: builtins.str | None = ...,
        metadata: collections.abc.Iterable[global___CustomPaymentMethodMetadata] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["country", b"country", "credentialID", b"credentialID", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["country", b"country", "credentialID", b"credentialID", "metadata", b"metadata", "type", b"type"]) -> None: ...

global___CustomPaymentMethod = CustomPaymentMethod

@typing.final
class CustomPaymentMethodMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str | None = ...,
        value: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

global___CustomPaymentMethodMetadata = CustomPaymentMethodMetadata

@typing.final
class PaymentInfoAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CPI_FIELD_NUMBER: builtins.int
    cpi: builtins.str
    def __init__(
        self,
        *,
        cpi: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cpi", b"cpi"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cpi", b"cpi"]) -> None: ...

global___PaymentInfoAction = PaymentInfoAction

@typing.final
class LabelReorderingAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SORTEDLABELIDS_FIELD_NUMBER: builtins.int
    @property
    def sortedLabelIDs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        sortedLabelIDs: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sortedLabelIDs", b"sortedLabelIDs"]) -> None: ...

global___LabelReorderingAction = LabelReorderingAction

@typing.final
class DeleteIndividualCallLogAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PEERJID_FIELD_NUMBER: builtins.int
    ISINCOMING_FIELD_NUMBER: builtins.int
    peerJID: builtins.str
    isIncoming: builtins.bool
    def __init__(
        self,
        *,
        peerJID: builtins.str | None = ...,
        isIncoming: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["isIncoming", b"isIncoming", "peerJID", b"peerJID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["isIncoming", b"isIncoming", "peerJID", b"peerJID"]) -> None: ...

global___DeleteIndividualCallLogAction = DeleteIndividualCallLogAction

@typing.final
class BotWelcomeRequestAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISSENT_FIELD_NUMBER: builtins.int
    isSent: builtins.bool
    def __init__(
        self,
        *,
        isSent: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["isSent", b"isSent"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["isSent", b"isSent"]) -> None: ...

global___BotWelcomeRequestAction = BotWelcomeRequestAction

@typing.final
class CallLogAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALLLOGRECORD_FIELD_NUMBER: builtins.int
    @property
    def callLogRecord(self) -> global___CallLogRecord: ...
    def __init__(
        self,
        *,
        callLogRecord: global___CallLogRecord | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["callLogRecord", b"callLogRecord"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["callLogRecord", b"callLogRecord"]) -> None: ...

global___CallLogAction = CallLogAction

@typing.final
class PrivacySettingRelayAllCalls(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISENABLED_FIELD_NUMBER: builtins.int
    isEnabled: builtins.bool
    def __init__(
        self,
        *,
        isEnabled: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["isEnabled", b"isEnabled"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["isEnabled", b"isEnabled"]) -> None: ...

global___PrivacySettingRelayAllCalls = PrivacySettingRelayAllCalls

@typing.final
class ExternalWebBetaAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISOPTIN_FIELD_NUMBER: builtins.int
    isOptIn: builtins.bool
    def __init__(
        self,
        *,
        isOptIn: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["isOptIn", b"isOptIn"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["isOptIn", b"isOptIn"]) -> None: ...

global___ExternalWebBetaAction = ExternalWebBetaAction

@typing.final
class MarketingMessageBroadcastAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPLIEDCOUNT_FIELD_NUMBER: builtins.int
    repliedCount: builtins.int
    def __init__(
        self,
        *,
        repliedCount: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["repliedCount", b"repliedCount"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["repliedCount", b"repliedCount"]) -> None: ...

global___MarketingMessageBroadcastAction = MarketingMessageBroadcastAction

@typing.final
class PnForLidChatAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PNJID_FIELD_NUMBER: builtins.int
    pnJID: builtins.str
    def __init__(
        self,
        *,
        pnJID: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pnJID", b"pnJID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["pnJID", b"pnJID"]) -> None: ...

global___PnForLidChatAction = PnForLidChatAction

@typing.final
class ChatAssignmentOpenedStatusAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHATOPENED_FIELD_NUMBER: builtins.int
    chatOpened: builtins.bool
    def __init__(
        self,
        *,
        chatOpened: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["chatOpened", b"chatOpened"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chatOpened", b"chatOpened"]) -> None: ...

global___ChatAssignmentOpenedStatusAction = ChatAssignmentOpenedStatusAction

@typing.final
class ChatAssignmentAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICEAGENTID_FIELD_NUMBER: builtins.int
    deviceAgentID: builtins.str
    def __init__(
        self,
        *,
        deviceAgentID: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["deviceAgentID", b"deviceAgentID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deviceAgentID", b"deviceAgentID"]) -> None: ...

global___ChatAssignmentAction = ChatAssignmentAction

@typing.final
class StickerAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    FILEENCSHA256_FIELD_NUMBER: builtins.int
    MEDIAKEY_FIELD_NUMBER: builtins.int
    MIMETYPE_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    DIRECTPATH_FIELD_NUMBER: builtins.int
    FILELENGTH_FIELD_NUMBER: builtins.int
    ISFAVORITE_FIELD_NUMBER: builtins.int
    DEVICEIDHINT_FIELD_NUMBER: builtins.int
    ISLOTTIE_FIELD_NUMBER: builtins.int
    URL: builtins.str
    fileEncSHA256: builtins.bytes
    mediaKey: builtins.bytes
    mimetype: builtins.str
    height: builtins.int
    width: builtins.int
    directPath: builtins.str
    fileLength: builtins.int
    isFavorite: builtins.bool
    deviceIDHint: builtins.int
    isLottie: builtins.bool
    def __init__(
        self,
        *,
        URL: builtins.str | None = ...,
        fileEncSHA256: builtins.bytes | None = ...,
        mediaKey: builtins.bytes | None = ...,
        mimetype: builtins.str | None = ...,
        height: builtins.int | None = ...,
        width: builtins.int | None = ...,
        directPath: builtins.str | None = ...,
        fileLength: builtins.int | None = ...,
        isFavorite: builtins.bool | None = ...,
        deviceIDHint: builtins.int | None = ...,
        isLottie: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["URL", b"URL", "deviceIDHint", b"deviceIDHint", "directPath", b"directPath", "fileEncSHA256", b"fileEncSHA256", "fileLength", b"fileLength", "height", b"height", "isFavorite", b"isFavorite", "isLottie", b"isLottie", "mediaKey", b"mediaKey", "mimetype", b"mimetype", "width", b"width"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["URL", b"URL", "deviceIDHint", b"deviceIDHint", "directPath", b"directPath", "fileEncSHA256", b"fileEncSHA256", "fileLength", b"fileLength", "height", b"height", "isFavorite", b"isFavorite", "isLottie", b"isLottie", "mediaKey", b"mediaKey", "mimetype", b"mimetype", "width", b"width"]) -> None: ...

global___StickerAction = StickerAction

@typing.final
class RemoveRecentStickerAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LASTSTICKERSENTTS_FIELD_NUMBER: builtins.int
    lastStickerSentTS: builtins.int
    def __init__(
        self,
        *,
        lastStickerSentTS: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["lastStickerSentTS", b"lastStickerSentTS"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["lastStickerSentTS", b"lastStickerSentTS"]) -> None: ...

global___RemoveRecentStickerAction = RemoveRecentStickerAction

@typing.final
class PrimaryVersionAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    version: builtins.str
    def __init__(
        self,
        *,
        version: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["version", b"version"]) -> None: ...

global___PrimaryVersionAction = PrimaryVersionAction

@typing.final
class NuxAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACKNOWLEDGED_FIELD_NUMBER: builtins.int
    acknowledged: builtins.bool
    def __init__(
        self,
        *,
        acknowledged: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["acknowledged", b"acknowledged"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["acknowledged", b"acknowledged"]) -> None: ...

global___NuxAction = NuxAction

@typing.final
class TimeFormatAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISTWENTYFOURHOURFORMATENABLED_FIELD_NUMBER: builtins.int
    isTwentyFourHourFormatEnabled: builtins.bool
    def __init__(
        self,
        *,
        isTwentyFourHourFormatEnabled: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["isTwentyFourHourFormatEnabled", b"isTwentyFourHourFormatEnabled"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["isTwentyFourHourFormatEnabled", b"isTwentyFourHourFormatEnabled"]) -> None: ...

global___TimeFormatAction = TimeFormatAction

@typing.final
class UserStatusMuteAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MUTED_FIELD_NUMBER: builtins.int
    muted: builtins.bool
    def __init__(
        self,
        *,
        muted: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["muted", b"muted"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["muted", b"muted"]) -> None: ...

global___UserStatusMuteAction = UserStatusMuteAction

@typing.final
class SubscriptionAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISDEACTIVATED_FIELD_NUMBER: builtins.int
    ISAUTORENEWING_FIELD_NUMBER: builtins.int
    EXPIRATIONDATE_FIELD_NUMBER: builtins.int
    isDeactivated: builtins.bool
    isAutoRenewing: builtins.bool
    expirationDate: builtins.int
    def __init__(
        self,
        *,
        isDeactivated: builtins.bool | None = ...,
        isAutoRenewing: builtins.bool | None = ...,
        expirationDate: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expirationDate", b"expirationDate", "isAutoRenewing", b"isAutoRenewing", "isDeactivated", b"isDeactivated"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["expirationDate", b"expirationDate", "isAutoRenewing", b"isAutoRenewing", "isDeactivated", b"isDeactivated"]) -> None: ...

global___SubscriptionAction = SubscriptionAction

@typing.final
class AgentAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DEVICEID_FIELD_NUMBER: builtins.int
    ISDELETED_FIELD_NUMBER: builtins.int
    name: builtins.str
    deviceID: builtins.int
    isDeleted: builtins.bool
    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
        deviceID: builtins.int | None = ...,
        isDeleted: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["deviceID", b"deviceID", "isDeleted", b"isDeleted", "name", b"name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deviceID", b"deviceID", "isDeleted", b"isDeleted", "name", b"name"]) -> None: ...

global___AgentAction = AgentAction

@typing.final
class AndroidUnsupportedActions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_FIELD_NUMBER: builtins.int
    allowed: builtins.bool
    def __init__(
        self,
        *,
        allowed: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["allowed", b"allowed"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allowed", b"allowed"]) -> None: ...

global___AndroidUnsupportedActions = AndroidUnsupportedActions

@typing.final
class PrimaryFeature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FLAGS_FIELD_NUMBER: builtins.int
    @property
    def flags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        flags: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["flags", b"flags"]) -> None: ...

global___PrimaryFeature = PrimaryFeature

@typing.final
class KeyExpiration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPIREDKEYEPOCH_FIELD_NUMBER: builtins.int
    expiredKeyEpoch: builtins.int
    def __init__(
        self,
        *,
        expiredKeyEpoch: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expiredKeyEpoch", b"expiredKeyEpoch"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["expiredKeyEpoch", b"expiredKeyEpoch"]) -> None: ...

global___KeyExpiration = KeyExpiration

@typing.final
class SyncActionMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    timestamp: builtins.int
    @property
    def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
    def __init__(
        self,
        *,
        key: waCommon.WACommon_pb2.MessageKey | None = ...,
        timestamp: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["key", b"key", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["key", b"key", "timestamp", b"timestamp"]) -> None: ...

global___SyncActionMessage = SyncActionMessage

@typing.final
class SyncActionMessageRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LASTMESSAGETIMESTAMP_FIELD_NUMBER: builtins.int
    LASTSYSTEMMESSAGETIMESTAMP_FIELD_NUMBER: builtins.int
    MESSAGES_FIELD_NUMBER: builtins.int
    lastMessageTimestamp: builtins.int
    lastSystemMessageTimestamp: builtins.int
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SyncActionMessage]: ...
    def __init__(
        self,
        *,
        lastMessageTimestamp: builtins.int | None = ...,
        lastSystemMessageTimestamp: builtins.int | None = ...,
        messages: collections.abc.Iterable[global___SyncActionMessage] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["lastMessageTimestamp", b"lastMessageTimestamp", "lastSystemMessageTimestamp", b"lastSystemMessageTimestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["lastMessageTimestamp", b"lastMessageTimestamp", "lastSystemMessageTimestamp", b"lastSystemMessageTimestamp", "messages", b"messages"]) -> None: ...

global___SyncActionMessageRange = SyncActionMessageRange

@typing.final
class UnarchiveChatsSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNARCHIVECHATS_FIELD_NUMBER: builtins.int
    unarchiveChats: builtins.bool
    def __init__(
        self,
        *,
        unarchiveChats: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["unarchiveChats", b"unarchiveChats"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["unarchiveChats", b"unarchiveChats"]) -> None: ...

global___UnarchiveChatsSetting = UnarchiveChatsSetting

@typing.final
class DeleteChatAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGERANGE_FIELD_NUMBER: builtins.int
    @property
    def messageRange(self) -> global___SyncActionMessageRange: ...
    def __init__(
        self,
        *,
        messageRange: global___SyncActionMessageRange | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["messageRange", b"messageRange"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["messageRange", b"messageRange"]) -> None: ...

global___DeleteChatAction = DeleteChatAction

@typing.final
class ClearChatAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGERANGE_FIELD_NUMBER: builtins.int
    @property
    def messageRange(self) -> global___SyncActionMessageRange: ...
    def __init__(
        self,
        *,
        messageRange: global___SyncActionMessageRange | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["messageRange", b"messageRange"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["messageRange", b"messageRange"]) -> None: ...

global___ClearChatAction = ClearChatAction

@typing.final
class MarkChatAsReadAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    READ_FIELD_NUMBER: builtins.int
    MESSAGERANGE_FIELD_NUMBER: builtins.int
    read: builtins.bool
    @property
    def messageRange(self) -> global___SyncActionMessageRange: ...
    def __init__(
        self,
        *,
        read: builtins.bool | None = ...,
        messageRange: global___SyncActionMessageRange | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["messageRange", b"messageRange", "read", b"read"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["messageRange", b"messageRange", "read", b"read"]) -> None: ...

global___MarkChatAsReadAction = MarkChatAsReadAction

@typing.final
class DeleteMessageForMeAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETEMEDIA_FIELD_NUMBER: builtins.int
    MESSAGETIMESTAMP_FIELD_NUMBER: builtins.int
    deleteMedia: builtins.bool
    messageTimestamp: builtins.int
    def __init__(
        self,
        *,
        deleteMedia: builtins.bool | None = ...,
        messageTimestamp: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["deleteMedia", b"deleteMedia", "messageTimestamp", b"messageTimestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deleteMedia", b"deleteMedia", "messageTimestamp", b"messageTimestamp"]) -> None: ...

global___DeleteMessageForMeAction = DeleteMessageForMeAction

@typing.final
class ArchiveChatAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARCHIVED_FIELD_NUMBER: builtins.int
    MESSAGERANGE_FIELD_NUMBER: builtins.int
    archived: builtins.bool
    @property
    def messageRange(self) -> global___SyncActionMessageRange: ...
    def __init__(
        self,
        *,
        archived: builtins.bool | None = ...,
        messageRange: global___SyncActionMessageRange | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["archived", b"archived", "messageRange", b"messageRange"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["archived", b"archived", "messageRange", b"messageRange"]) -> None: ...

global___ArchiveChatAction = ArchiveChatAction

@typing.final
class RecentEmojiWeightsAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WEIGHTS_FIELD_NUMBER: builtins.int
    @property
    def weights(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecentEmojiWeight]: ...
    def __init__(
        self,
        *,
        weights: collections.abc.Iterable[global___RecentEmojiWeight] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["weights", b"weights"]) -> None: ...

global___RecentEmojiWeightsAction = RecentEmojiWeightsAction

@typing.final
class LabelAssociationAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABELED_FIELD_NUMBER: builtins.int
    labeled: builtins.bool
    def __init__(
        self,
        *,
        labeled: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["labeled", b"labeled"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["labeled", b"labeled"]) -> None: ...

global___LabelAssociationAction = LabelAssociationAction

@typing.final
class QuickReplyAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHORTCUT_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    KEYWORDS_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    DELETED_FIELD_NUMBER: builtins.int
    shortcut: builtins.str
    message: builtins.str
    count: builtins.int
    deleted: builtins.bool
    @property
    def keywords(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        shortcut: builtins.str | None = ...,
        message: builtins.str | None = ...,
        keywords: collections.abc.Iterable[builtins.str] | None = ...,
        count: builtins.int | None = ...,
        deleted: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["count", b"count", "deleted", b"deleted", "message", b"message", "shortcut", b"shortcut"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["count", b"count", "deleted", b"deleted", "keywords", b"keywords", "message", b"message", "shortcut", b"shortcut"]) -> None: ...

global___QuickReplyAction = QuickReplyAction

@typing.final
class LocaleSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCALE_FIELD_NUMBER: builtins.int
    locale: builtins.str
    def __init__(
        self,
        *,
        locale: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["locale", b"locale"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["locale", b"locale"]) -> None: ...

global___LocaleSetting = LocaleSetting

@typing.final
class PushNameSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["name", b"name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___PushNameSetting = PushNameSetting

@typing.final
class SecurityNotificationSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOWNOTIFICATION_FIELD_NUMBER: builtins.int
    showNotification: builtins.bool
    def __init__(
        self,
        *,
        showNotification: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["showNotification", b"showNotification"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["showNotification", b"showNotification"]) -> None: ...

global___SecurityNotificationSetting = SecurityNotificationSetting

@typing.final
class PinAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PINNED_FIELD_NUMBER: builtins.int
    pinned: builtins.bool
    def __init__(
        self,
        *,
        pinned: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pinned", b"pinned"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["pinned", b"pinned"]) -> None: ...

global___PinAction = PinAction

@typing.final
class MuteAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MUTED_FIELD_NUMBER: builtins.int
    MUTEENDTIMESTAMP_FIELD_NUMBER: builtins.int
    AUTOMUTED_FIELD_NUMBER: builtins.int
    muted: builtins.bool
    muteEndTimestamp: builtins.int
    autoMuted: builtins.bool
    def __init__(
        self,
        *,
        muted: builtins.bool | None = ...,
        muteEndTimestamp: builtins.int | None = ...,
        autoMuted: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["autoMuted", b"autoMuted", "muteEndTimestamp", b"muteEndTimestamp", "muted", b"muted"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["autoMuted", b"autoMuted", "muteEndTimestamp", b"muteEndTimestamp", "muted", b"muted"]) -> None: ...

global___MuteAction = MuteAction

@typing.final
class ContactAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FULLNAME_FIELD_NUMBER: builtins.int
    FIRSTNAME_FIELD_NUMBER: builtins.int
    LIDJID_FIELD_NUMBER: builtins.int
    SAVEONPRIMARYADDRESSBOOK_FIELD_NUMBER: builtins.int
    PNJID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    fullName: builtins.str
    firstName: builtins.str
    lidJID: builtins.str
    saveOnPrimaryAddressbook: builtins.bool
    pnJID: builtins.str
    username: builtins.str
    def __init__(
        self,
        *,
        fullName: builtins.str | None = ...,
        firstName: builtins.str | None = ...,
        lidJID: builtins.str | None = ...,
        saveOnPrimaryAddressbook: builtins.bool | None = ...,
        pnJID: builtins.str | None = ...,
        username: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["firstName", b"firstName", "fullName", b"fullName", "lidJID", b"lidJID", "pnJID", b"pnJID", "saveOnPrimaryAddressbook", b"saveOnPrimaryAddressbook", "username", b"username"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["firstName", b"firstName", "fullName", b"fullName", "lidJID", b"lidJID", "pnJID", b"pnJID", "saveOnPrimaryAddressbook", b"saveOnPrimaryAddressbook", "username", b"username"]) -> None: ...

global___ContactAction = ContactAction

@typing.final
class StarAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STARRED_FIELD_NUMBER: builtins.int
    starred: builtins.bool
    def __init__(
        self,
        *,
        starred: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["starred", b"starred"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["starred", b"starred"]) -> None: ...

global___StarAction = StarAction

@typing.final
class SyncActionData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDEX_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    PADDING_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    index: builtins.bytes
    padding: builtins.bytes
    version: builtins.int
    @property
    def value(self) -> global___SyncActionValue: ...
    def __init__(
        self,
        *,
        index: builtins.bytes | None = ...,
        value: global___SyncActionValue | None = ...,
        padding: builtins.bytes | None = ...,
        version: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["index", b"index", "padding", b"padding", "value", b"value", "version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["index", b"index", "padding", b"padding", "value", b"value", "version", b"version"]) -> None: ...

global___SyncActionData = SyncActionData
