"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MiTransportAdminMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class GroupImageChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Action:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MiTransportAdminMessage.GroupImageChanged._Action.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            CHANGED: MiTransportAdminMessage.GroupImageChanged._Action.ValueType  # 1
            REMOVED: MiTransportAdminMessage.GroupImageChanged._Action.ValueType  # 2

        class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
        CHANGED: MiTransportAdminMessage.GroupImageChanged.Action.ValueType  # 1
        REMOVED: MiTransportAdminMessage.GroupImageChanged.Action.ValueType  # 2

        ACTION_FIELD_NUMBER: builtins.int
        action: global___MiTransportAdminMessage.GroupImageChanged.Action.ValueType
        def __init__(
            self,
            *,
            action: global___MiTransportAdminMessage.GroupImageChanged.Action.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action"]) -> None: ...

    @typing.final
    class MessagePinned(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Action:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MiTransportAdminMessage.MessagePinned._Action.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            PINNED: MiTransportAdminMessage.MessagePinned._Action.ValueType  # 1
            UNPINNED: MiTransportAdminMessage.MessagePinned._Action.ValueType  # 2

        class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
        PINNED: MiTransportAdminMessage.MessagePinned.Action.ValueType  # 1
        UNPINNED: MiTransportAdminMessage.MessagePinned.Action.ValueType  # 2

        ACTION_FIELD_NUMBER: builtins.int
        action: global___MiTransportAdminMessage.MessagePinned.Action.ValueType
        def __init__(
            self,
            *,
            action: global___MiTransportAdminMessage.MessagePinned.Action.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action"]) -> None: ...

    @typing.final
    class GroupMembershipAddModeChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Mode:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MiTransportAdminMessage.GroupMembershipAddModeChanged._Mode.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            ALL_MEMBERS: MiTransportAdminMessage.GroupMembershipAddModeChanged._Mode.ValueType  # 1
            ADMINS_ONLY: MiTransportAdminMessage.GroupMembershipAddModeChanged._Mode.ValueType  # 2

        class Mode(_Mode, metaclass=_ModeEnumTypeWrapper): ...
        ALL_MEMBERS: MiTransportAdminMessage.GroupMembershipAddModeChanged.Mode.ValueType  # 1
        ADMINS_ONLY: MiTransportAdminMessage.GroupMembershipAddModeChanged.Mode.ValueType  # 2

        MODE_FIELD_NUMBER: builtins.int
        mode: global___MiTransportAdminMessage.GroupMembershipAddModeChanged.Mode.ValueType
        def __init__(
            self,
            *,
            mode: global___MiTransportAdminMessage.GroupMembershipAddModeChanged.Mode.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["mode", b"mode"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["mode", b"mode"]) -> None: ...

    @typing.final
    class GroupAdminChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Action:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MiTransportAdminMessage.GroupAdminChanged._Action.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            ADDED: MiTransportAdminMessage.GroupAdminChanged._Action.ValueType  # 1
            REMOVED: MiTransportAdminMessage.GroupAdminChanged._Action.ValueType  # 2

        class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
        ADDED: MiTransportAdminMessage.GroupAdminChanged.Action.ValueType  # 1
        REMOVED: MiTransportAdminMessage.GroupAdminChanged.Action.ValueType  # 2

        TARGETUSERID_FIELD_NUMBER: builtins.int
        ACTION_FIELD_NUMBER: builtins.int
        action: global___MiTransportAdminMessage.GroupAdminChanged.Action.ValueType
        @property
        def targetUserID(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            targetUserID: collections.abc.Iterable[builtins.str] | None = ...,
            action: global___MiTransportAdminMessage.GroupAdminChanged.Action.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "targetUserID", b"targetUserID"]) -> None: ...

    @typing.final
    class GroupParticipantChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Action:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MiTransportAdminMessage.GroupParticipantChanged._Action.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            ADDED: MiTransportAdminMessage.GroupParticipantChanged._Action.ValueType  # 1
            REMOVED: MiTransportAdminMessage.GroupParticipantChanged._Action.ValueType  # 2

        class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
        ADDED: MiTransportAdminMessage.GroupParticipantChanged.Action.ValueType  # 1
        REMOVED: MiTransportAdminMessage.GroupParticipantChanged.Action.ValueType  # 2

        TARGETUSERID_FIELD_NUMBER: builtins.int
        ACTION_FIELD_NUMBER: builtins.int
        action: global___MiTransportAdminMessage.GroupParticipantChanged.Action.ValueType
        @property
        def targetUserID(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            targetUserID: collections.abc.Iterable[builtins.str] | None = ...,
            action: global___MiTransportAdminMessage.GroupParticipantChanged.Action.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "targetUserID", b"targetUserID"]) -> None: ...

    @typing.final
    class DisappearingSettingChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DISAPPEARINGSETTINGDURATIONSECONDS_FIELD_NUMBER: builtins.int
        OLDDISAPPEARINGSETTINGDURATIONSECONDS_FIELD_NUMBER: builtins.int
        disappearingSettingDurationSeconds: builtins.int
        oldDisappearingSettingDurationSeconds: builtins.int
        def __init__(
            self,
            *,
            disappearingSettingDurationSeconds: builtins.int | None = ...,
            oldDisappearingSettingDurationSeconds: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["disappearingSettingDurationSeconds", b"disappearingSettingDurationSeconds", "oldDisappearingSettingDurationSeconds", b"oldDisappearingSettingDurationSeconds"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["disappearingSettingDurationSeconds", b"disappearingSettingDurationSeconds", "oldDisappearingSettingDurationSeconds", b"oldDisappearingSettingDurationSeconds"]) -> None: ...

    @typing.final
    class IconChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        THREADICON_FIELD_NUMBER: builtins.int
        threadIcon: builtins.str
        def __init__(
            self,
            *,
            threadIcon: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["threadIcon", b"threadIcon"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["threadIcon", b"threadIcon"]) -> None: ...

    @typing.final
    class LinkCta(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class UkOsaAdminText(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            INITIATORUSERID_FIELD_NUMBER: builtins.int
            initiatorUserID: builtins.str
            def __init__(
                self,
                *,
                initiatorUserID: builtins.str | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["initiatorUserID", b"initiatorUserID"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["initiatorUserID", b"initiatorUserID"]) -> None: ...

        UKOSAADMINTEXT_FIELD_NUMBER: builtins.int
        @property
        def ukOsaAdminText(self) -> global___MiTransportAdminMessage.LinkCta.UkOsaAdminText: ...
        def __init__(
            self,
            *,
            ukOsaAdminText: global___MiTransportAdminMessage.LinkCta.UkOsaAdminText | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["content", b"content", "ukOsaAdminText", b"ukOsaAdminText"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["content", b"content", "ukOsaAdminText", b"ukOsaAdminText"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["content", b"content"]) -> typing.Literal["ukOsaAdminText"] | None: ...

    @typing.final
    class QuickReactionChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EMOJINAME_FIELD_NUMBER: builtins.int
        emojiName: builtins.str
        def __init__(
            self,
            *,
            emojiName: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["emojiName", b"emojiName"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["emojiName", b"emojiName"]) -> None: ...

    @typing.final
    class GroupNameChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        GROUPNAME_FIELD_NUMBER: builtins.int
        groupName: builtins.str
        def __init__(
            self,
            *,
            groupName: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["groupName", b"groupName"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["groupName", b"groupName"]) -> None: ...

    @typing.final
    class NicknameChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TARGETUSERID_FIELD_NUMBER: builtins.int
        NICKNAME_FIELD_NUMBER: builtins.int
        targetUserID: builtins.str
        nickname: builtins.str
        def __init__(
            self,
            *,
            targetUserID: builtins.str | None = ...,
            nickname: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["nickname", b"nickname", "targetUserID", b"targetUserID"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["nickname", b"nickname", "targetUserID", b"targetUserID"]) -> None: ...

    @typing.final
    class ChatThemeChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        THEMENAME_FIELD_NUMBER: builtins.int
        THEMEEMOJI_FIELD_NUMBER: builtins.int
        THEMETYPE_FIELD_NUMBER: builtins.int
        themeName: builtins.str
        themeEmoji: builtins.str
        themeType: builtins.int
        def __init__(
            self,
            *,
            themeName: builtins.str | None = ...,
            themeEmoji: builtins.str | None = ...,
            themeType: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["themeEmoji", b"themeEmoji", "themeName", b"themeName", "themeType", b"themeType"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["themeEmoji", b"themeEmoji", "themeName", b"themeName", "themeType", b"themeType"]) -> None: ...

    CHATTHEMECHANGED_FIELD_NUMBER: builtins.int
    NICKNAMECHANGED_FIELD_NUMBER: builtins.int
    GROUPPARTICIPANTCHANGED_FIELD_NUMBER: builtins.int
    GROUPADMINCHANGED_FIELD_NUMBER: builtins.int
    GROUPNAMECHANGED_FIELD_NUMBER: builtins.int
    GROUPMEMBERSHIPADDMODECHANGED_FIELD_NUMBER: builtins.int
    MESSAGEPINNED_FIELD_NUMBER: builtins.int
    GROUPIMAGECHANGED_FIELD_NUMBER: builtins.int
    QUICKREACTIONCHANGED_FIELD_NUMBER: builtins.int
    LINKCTA_FIELD_NUMBER: builtins.int
    ICONCHANGED_FIELD_NUMBER: builtins.int
    DISAPPEARINGSETTINGCHANGED_FIELD_NUMBER: builtins.int
    @property
    def chatThemeChanged(self) -> global___MiTransportAdminMessage.ChatThemeChanged: ...
    @property
    def nicknameChanged(self) -> global___MiTransportAdminMessage.NicknameChanged: ...
    @property
    def groupParticipantChanged(self) -> global___MiTransportAdminMessage.GroupParticipantChanged: ...
    @property
    def groupAdminChanged(self) -> global___MiTransportAdminMessage.GroupAdminChanged: ...
    @property
    def groupNameChanged(self) -> global___MiTransportAdminMessage.GroupNameChanged: ...
    @property
    def groupMembershipAddModeChanged(self) -> global___MiTransportAdminMessage.GroupMembershipAddModeChanged: ...
    @property
    def messagePinned(self) -> global___MiTransportAdminMessage.MessagePinned: ...
    @property
    def groupImageChanged(self) -> global___MiTransportAdminMessage.GroupImageChanged: ...
    @property
    def quickReactionChanged(self) -> global___MiTransportAdminMessage.QuickReactionChanged: ...
    @property
    def linkCta(self) -> global___MiTransportAdminMessage.LinkCta: ...
    @property
    def iconChanged(self) -> global___MiTransportAdminMessage.IconChanged: ...
    @property
    def disappearingSettingChanged(self) -> global___MiTransportAdminMessage.DisappearingSettingChanged: ...
    def __init__(
        self,
        *,
        chatThemeChanged: global___MiTransportAdminMessage.ChatThemeChanged | None = ...,
        nicknameChanged: global___MiTransportAdminMessage.NicknameChanged | None = ...,
        groupParticipantChanged: global___MiTransportAdminMessage.GroupParticipantChanged | None = ...,
        groupAdminChanged: global___MiTransportAdminMessage.GroupAdminChanged | None = ...,
        groupNameChanged: global___MiTransportAdminMessage.GroupNameChanged | None = ...,
        groupMembershipAddModeChanged: global___MiTransportAdminMessage.GroupMembershipAddModeChanged | None = ...,
        messagePinned: global___MiTransportAdminMessage.MessagePinned | None = ...,
        groupImageChanged: global___MiTransportAdminMessage.GroupImageChanged | None = ...,
        quickReactionChanged: global___MiTransportAdminMessage.QuickReactionChanged | None = ...,
        linkCta: global___MiTransportAdminMessage.LinkCta | None = ...,
        iconChanged: global___MiTransportAdminMessage.IconChanged | None = ...,
        disappearingSettingChanged: global___MiTransportAdminMessage.DisappearingSettingChanged | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["chatThemeChanged", b"chatThemeChanged", "content", b"content", "disappearingSettingChanged", b"disappearingSettingChanged", "groupAdminChanged", b"groupAdminChanged", "groupImageChanged", b"groupImageChanged", "groupMembershipAddModeChanged", b"groupMembershipAddModeChanged", "groupNameChanged", b"groupNameChanged", "groupParticipantChanged", b"groupParticipantChanged", "iconChanged", b"iconChanged", "linkCta", b"linkCta", "messagePinned", b"messagePinned", "nicknameChanged", b"nicknameChanged", "quickReactionChanged", b"quickReactionChanged"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chatThemeChanged", b"chatThemeChanged", "content", b"content", "disappearingSettingChanged", b"disappearingSettingChanged", "groupAdminChanged", b"groupAdminChanged", "groupImageChanged", b"groupImageChanged", "groupMembershipAddModeChanged", b"groupMembershipAddModeChanged", "groupNameChanged", b"groupNameChanged", "groupParticipantChanged", b"groupParticipantChanged", "iconChanged", b"iconChanged", "linkCta", b"linkCta", "messagePinned", b"messagePinned", "nicknameChanged", b"nicknameChanged", "quickReactionChanged", b"quickReactionChanged"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["content", b"content"]) -> typing.Literal["chatThemeChanged", "nicknameChanged", "groupParticipantChanged", "groupAdminChanged", "groupNameChanged", "groupMembershipAddModeChanged", "messagePinned", "groupImageChanged", "quickReactionChanged", "linkCta", "iconChanged", "disappearingSettingChanged"] | None: ...

global___MiTransportAdminMessage = MiTransportAdminMessage
