"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Subprotocol(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAYLOAD_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    payload: builtins.bytes
    version: builtins.int
    def __init__(
        self,
        *,
        payload: builtins.bytes | None = ...,
        version: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["payload", b"payload", "version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["payload", b"payload", "version", b"version"]) -> None: ...

global___Subprotocol = Subprotocol
