"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ICDCIdentityList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEQ_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    DEVICES_FIELD_NUMBER: builtins.int
    SIGNINGDEVICEINDEX_FIELD_NUMBER: builtins.int
    seq: builtins.int
    timestamp: builtins.int
    signingDeviceIndex: builtins.int
    @property
    def devices(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...
    def __init__(
        self,
        *,
        seq: builtins.int | None = ...,
        timestamp: builtins.int | None = ...,
        devices: collections.abc.Iterable[builtins.bytes] | None = ...,
        signingDeviceIndex: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["seq", b"seq", "signingDeviceIndex", b"signingDeviceIndex", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["devices", b"devices", "seq", b"seq", "signingDeviceIndex", b"signingDeviceIndex", "timestamp", b"timestamp"]) -> None: ...

global___ICDCIdentityList = ICDCIdentityList

@typing.final
class SignedICDCIdentityList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DETAILS_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    details: builtins.bytes
    signature: builtins.bytes
    def __init__(
        self,
        *,
        details: builtins.bytes | None = ...,
        signature: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["details", b"details", "signature", b"signature"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["details", b"details", "signature", b"signature"]) -> None: ...

global___SignedICDCIdentityList = SignedICDCIdentityList
