# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waArmadilloTransportEvent/WAArmadilloTransportEvent.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waArmadilloTransportEvent/WAArmadilloTransportEvent.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9waArmadilloTransportEvent/WAArmadilloTransportEvent.proto\x12\x19WAArmadilloTransportEvent\"\xdb\x06\n\x0eTransportEvent\x12L\n\x0bplaceholder\x18\x01 \x01(\x0b\x32\x35.WAArmadilloTransportEvent.TransportEvent.PlaceholderH\x00\x12@\n\x05\x65vent\x18\x02 \x01(\x0b\x32/.WAArmadilloTransportEvent.TransportEvent.EventH\x00\x1a\x9a\x04\n\x05\x45vent\x12T\n\x0c\x64\x65viceChange\x18\x01 \x01(\x0b\x32<.WAArmadilloTransportEvent.TransportEvent.Event.DeviceChangeH\x00\x12N\n\ticdcAlert\x18\x02 \x01(\x0b\x32\x39.WAArmadilloTransportEvent.TransportEvent.Event.IcdcAlertH\x00\x1a\x86\x01\n\tIcdcAlert\x12L\n\x04type\x18\x01 \x01(\x0e\x32>.WAArmadilloTransportEvent.TransportEvent.Event.IcdcAlert.Type\"+\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08\x44\x45TECTED\x10\x01\x12\x0b\n\x07\x43LEARED\x10\x02\x1a\xd8\x01\n\x0c\x44\x65viceChange\x12O\n\x04type\x18\x01 \x01(\x0e\x32\x41.WAArmadilloTransportEvent.TransportEvent.Event.DeviceChange.Type\x12\x12\n\ndeviceName\x18\x02 \x01(\t\x12\x16\n\x0e\x64\x65vicePlatform\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65viceModel\x18\x04 \x01(\t\"6\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x41\x44\x44\x45\x44\x10\x01\x12\x0b\n\x07REMOVED\x10\x02\x12\x0c\n\x08REPLACED\x10\x03\x42\x07\n\x05\x65vent\x1a\x90\x01\n\x0bPlaceholder\x12H\n\x04type\x18\x01 \x01(\x0e\x32:.WAArmadilloTransportEvent.TransportEvent.Placeholder.Type\"7\n\x04Type\x12\x16\n\x12\x44\x45\x43RYPTION_FAILURE\x10\x01\x12\x17\n\x13UNAVAILABLE_MESSAGE\x10\x02\x42\t\n\x07\x63ontentB5Z3go.mau.fi/whatsmeow/proto/waArmadilloTransportEvent')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waArmadilloTransportEvent.WAArmadilloTransportEvent_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3go.mau.fi/whatsmeow/proto/waArmadilloTransportEvent'
  _globals['_TRANSPORTEVENT']._serialized_start=89
  _globals['_TRANSPORTEVENT']._serialized_end=948
  _globals['_TRANSPORTEVENT_EVENT']._serialized_start=252
  _globals['_TRANSPORTEVENT_EVENT']._serialized_end=790
  _globals['_TRANSPORTEVENT_EVENT_ICDCALERT']._serialized_start=428
  _globals['_TRANSPORTEVENT_EVENT_ICDCALERT']._serialized_end=562
  _globals['_TRANSPORTEVENT_EVENT_ICDCALERT_TYPE']._serialized_start=519
  _globals['_TRANSPORTEVENT_EVENT_ICDCALERT_TYPE']._serialized_end=562
  _globals['_TRANSPORTEVENT_EVENT_DEVICECHANGE']._serialized_start=565
  _globals['_TRANSPORTEVENT_EVENT_DEVICECHANGE']._serialized_end=781
  _globals['_TRANSPORTEVENT_EVENT_DEVICECHANGE_TYPE']._serialized_start=727
  _globals['_TRANSPORTEVENT_EVENT_DEVICECHANGE_TYPE']._serialized_end=781
  _globals['_TRANSPORTEVENT_PLACEHOLDER']._serialized_start=793
  _globals['_TRANSPORTEVENT_PLACEHOLDER']._serialized_end=937
  _globals['_TRANSPORTEVENT_PLACEHOLDER_TYPE']._serialized_start=882
  _globals['_TRANSPORTEVENT_PLACEHOLDER_TYPE']._serialized_end=937
# @@protoc_insertion_point(module_scope)
