# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waAdv/WAAdv.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waAdv/WAAdv.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11waAdv/WAAdv.proto\x12\x05WAAdv\"\x92\x01\n\x0f\x41\x44VKeyIndexList\x12\r\n\x05rawID\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x14\n\x0c\x63urrentIndex\x18\x03 \x01(\r\x12\x18\n\x0cvalidIndexes\x18\x04 \x03(\rB\x02\x10\x01\x12-\n\x0b\x61\x63\x63ountType\x18\x05 \x01(\x0e\x32\x18.WAAdv.ADVEncryptionType\"_\n\x15\x41\x44VSignedKeyIndexList\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\x0c\x12\x18\n\x10\x61\x63\x63ountSignature\x18\x02 \x01(\x0c\x12\x1b\n\x13\x61\x63\x63ountSignatureKey\x18\x03 \x01(\x0c\"\xa4\x01\n\x11\x41\x44VDeviceIdentity\x12\r\n\x05rawID\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x10\n\x08keyIndex\x18\x03 \x01(\r\x12-\n\x0b\x61\x63\x63ountType\x18\x04 \x01(\x0e\x32\x18.WAAdv.ADVEncryptionType\x12,\n\ndeviceType\x18\x05 \x01(\x0e\x32\x18.WAAdv.ADVEncryptionType\"z\n\x17\x41\x44VSignedDeviceIdentity\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\x0c\x12\x1b\n\x13\x61\x63\x63ountSignatureKey\x18\x02 \x01(\x0c\x12\x18\n\x10\x61\x63\x63ountSignature\x18\x03 \x01(\x0c\x12\x17\n\x0f\x64\x65viceSignature\x18\x04 \x01(\x0c\"k\n\x1b\x41\x44VSignedDeviceIdentityHMAC\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\x0c\x12\x0c\n\x04HMAC\x18\x02 \x01(\x0c\x12-\n\x0b\x61\x63\x63ountType\x18\x03 \x01(\x0e\x32\x18.WAAdv.ADVEncryptionType*)\n\x11\x41\x44VEncryptionType\x12\x08\n\x04\x45\x32\x45\x45\x10\x00\x12\n\n\x06HOSTED\x10\x01\x42!Z\x1fgo.mau.fi/whatsmeow/proto/waAdv')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waAdv.WAAdv_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\037go.mau.fi/whatsmeow/proto/waAdv'
  _globals['_ADVKEYINDEXLIST'].fields_by_name['validIndexes']._loaded_options = None
  _globals['_ADVKEYINDEXLIST'].fields_by_name['validIndexes']._serialized_options = b'\020\001'
  _globals['_ADVENCRYPTIONTYPE']._serialized_start=674
  _globals['_ADVENCRYPTIONTYPE']._serialized_end=715
  _globals['_ADVKEYINDEXLIST']._serialized_start=29
  _globals['_ADVKEYINDEXLIST']._serialized_end=175
  _globals['_ADVSIGNEDKEYINDEXLIST']._serialized_start=177
  _globals['_ADVSIGNEDKEYINDEXLIST']._serialized_end=272
  _globals['_ADVDEVICEIDENTITY']._serialized_start=275
  _globals['_ADVDEVICEIDENTITY']._serialized_end=439
  _globals['_ADVSIGNEDDEVICEIDENTITY']._serialized_start=441
  _globals['_ADVSIGNEDDEVICEIDENTITY']._serialized_end=563
  _globals['_ADVSIGNEDDEVICEIDENTITYHMAC']._serialized_start=565
  _globals['_ADVSIGNEDDEVICEIDENTITYHMAC']._serialized_end=672
# @@protoc_insertion_point(module_scope)
