# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waDeviceCapabilities/WAProtobufsDeviceCapabilities.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waDeviceCapabilities/WAProtobufsDeviceCapabilities.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8waDeviceCapabilities/WAProtobufsDeviceCapabilities.proto\x12\x1dWAProtobufsDeviceCapabilities\"\xbb\x02\n\x12\x44\x65viceCapabilities\x12\x64\n\x14\x63hatLockSupportLevel\x18\x01 \x01(\x0e\x32\x46.WAProtobufsDeviceCapabilities.DeviceCapabilities.ChatLockSupportLevel\x12T\n\x0clidMigration\x18\x02 \x01(\x0b\x32>.WAProtobufsDeviceCapabilities.DeviceCapabilities.LIDMigration\x1a\x30\n\x0cLIDMigration\x12 \n\x18\x63hatDbMigrationTimestamp\x18\x01 \x01(\x04\"7\n\x14\x43hatLockSupportLevel\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07MINIMAL\x10\x01\x12\x08\n\x04\x46ULL\x10\x02\x42\x30Z.go.mau.fi/whatsmeow/proto/waDeviceCapabilities')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waDeviceCapabilities.WAProtobufsDeviceCapabilities_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z.go.mau.fi/whatsmeow/proto/waDeviceCapabilities'
  _globals['_DEVICECAPABILITIES']._serialized_start=92
  _globals['_DEVICECAPABILITIES']._serialized_end=407
  _globals['_DEVICECAPABILITIES_LIDMIGRATION']._serialized_start=302
  _globals['_DEVICECAPABILITIES_LIDMIGRATION']._serialized_end=350
  _globals['_DEVICECAPABILITIES_CHATLOCKSUPPORTLEVEL']._serialized_start=352
  _globals['_DEVICECAPABILITIES_CHATLOCKSUPPORTLEVEL']._serialized_end=407
# @@protoc_insertion_point(module_scope)
