# class InvalidInviteLink(Exception):
#     pass


class UploadError(Exception):
    pass


class DownloadError(Exception):
    pass


class InviteLinkError(Exception):
    pass


class GetGroupInfoError(Exception):
    pass


class SetGroupPhotoError(Exception):
    pass


class GetGroupInviteLinkError(Exception):
    pass


class CreateGroupError(Exception):
    pass


class IsOnWhatsAppError(Exception):
    pass


class GetUserInfoError(Exception):
    pass


class SendMessageError(Exception):
    pass


class BuildPollVoteError(Exception):
    pass


class CreateNewsletterError(Exception):
    pass


class FollowNewsletterError(Exception):
    pass


class GetBlocklistError(Exception):
    pass


class GetContactQrLinkError(Exception):
    pass


class GetGroupRequestParticipantsError(Exception):
    pass


class GetJoinedGroupsError(Exception):
    pass


class GetLinkedGroupParticipantsError(Exception):
    pass


class GetNewsletterInfoError(Exception):
    pass


class GetNewsletterInfoWithInviteError(Exception):
    pass


class GetNewsletterMessageUpdateError(Exception):
    pass


class GetNewsletterMessagesError(Exception):
    pass


class GetProfilePictureError(Exception):
    pass


class GetStatusPrivacyError(Exception):
    pass


class GetSubGroupsError(Exception):
    pass


class GetSubscribedNewslettersError(Exception):
    pass


class GetUserDevicesError(Exception):
    pass


class JoinGroupWithInviteError(Exception):
    pass


class LinkGroupError(Exception):
    pass


class LogoutError(Exception):
    pass


class MarkReadError(Exception):
    pass


class NewsletterMarkViewedError(Exception):
    pass


class NewsletterSendReactionError(Exception):
    pass


class NewsletterSubscribeLiveUpdatesError(Exception):
    pass


class NewsletterToggleMuteError(Exception):
    pass


class ResolveContactQRLinkError(Exception):
    pass


class ResolveBusinessMessageLinkError(Exception):
    pass


class SendAppStateError(Exception):
    pass


class SetDefaultDisappearingTimerError(Exception):
    pass


class SetDisappearingTimerError(Exception):
    pass


class SetGroupAnnounceError(Exception):
    pass


class SetGroupLockedError(Exception):
    pass


class SetGroupTopicError(Exception):
    pass


class SetPrivacySettingError(Exception):
    pass


class SetPassiveError(Exception):
    pass


class SetStatusMessageError(Exception):
    pass


class SubscribePresenceError(Exception):
    pass


class UnfollowNewsletterError(Exception):
    pass


class UnlinkGroupErro(Exception):
    pass


class UnlinkGroupError(Exception):
    pass


class UpdateBlocklistError(Exception):
    pass


class UpdateGroupParticipantsError(Exception):
    pass


class UnsupportedEvent(Exception):
    pass


class ContactStoreError(Exception):
    pass


class FFProbeError(Exception):
    pass


class PutMutedUntilError(Exception):
    pass


class PutPinnedError(Exception):
    pass


class PutArchivedError(Exception):
    pass


class GetChatSettingsError(Exception):
    pass


class SendPresenceError(Exception):
    pass


class DecryptPollVoteError(Exception):
    pass
