"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class NoiseCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Details(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SERIAL_FIELD_NUMBER: builtins.int
        ISSUER_FIELD_NUMBER: builtins.int
        EXPIRES_FIELD_NUMBER: builtins.int
        SUBJECT_FIELD_NUMBER: builtins.int
        KEY_FIELD_NUMBER: builtins.int
        serial: builtins.int
        issuer: builtins.str
        expires: builtins.int
        subject: builtins.str
        key: builtins.bytes
        def __init__(
            self,
            *,
            serial: builtins.int | None = ...,
            issuer: builtins.str | None = ...,
            expires: builtins.int | None = ...,
            subject: builtins.str | None = ...,
            key: builtins.bytes | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["expires", b"expires", "issuer", b"issuer", "key", b"key", "serial", b"serial", "subject", b"subject"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["expires", b"expires", "issuer", b"issuer", "key", b"key", "serial", b"serial", "subject", b"subject"]) -> None: ...

    DETAILS_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    details: builtins.bytes
    signature: builtins.bytes
    def __init__(
        self,
        *,
        details: builtins.bytes | None = ...,
        signature: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["details", b"details", "signature", b"signature"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["details", b"details", "signature", b"signature"]) -> None: ...

global___NoiseCertificate = NoiseCertificate

@typing.final
class CertChain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class NoiseCertificate(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class Details(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            SERIAL_FIELD_NUMBER: builtins.int
            ISSUERSERIAL_FIELD_NUMBER: builtins.int
            KEY_FIELD_NUMBER: builtins.int
            NOTBEFORE_FIELD_NUMBER: builtins.int
            NOTAFTER_FIELD_NUMBER: builtins.int
            serial: builtins.int
            issuerSerial: builtins.int
            key: builtins.bytes
            notBefore: builtins.int
            notAfter: builtins.int
            def __init__(
                self,
                *,
                serial: builtins.int | None = ...,
                issuerSerial: builtins.int | None = ...,
                key: builtins.bytes | None = ...,
                notBefore: builtins.int | None = ...,
                notAfter: builtins.int | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["issuerSerial", b"issuerSerial", "key", b"key", "notAfter", b"notAfter", "notBefore", b"notBefore", "serial", b"serial"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["issuerSerial", b"issuerSerial", "key", b"key", "notAfter", b"notAfter", "notBefore", b"notBefore", "serial", b"serial"]) -> None: ...

        DETAILS_FIELD_NUMBER: builtins.int
        SIGNATURE_FIELD_NUMBER: builtins.int
        details: builtins.bytes
        signature: builtins.bytes
        def __init__(
            self,
            *,
            details: builtins.bytes | None = ...,
            signature: builtins.bytes | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["details", b"details", "signature", b"signature"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["details", b"details", "signature", b"signature"]) -> None: ...

    LEAF_FIELD_NUMBER: builtins.int
    INTERMEDIATE_FIELD_NUMBER: builtins.int
    @property
    def leaf(self) -> global___CertChain.NoiseCertificate: ...
    @property
    def intermediate(self) -> global___CertChain.NoiseCertificate: ...
    def __init__(
        self,
        *,
        leaf: global___CertChain.NoiseCertificate | None = ...,
        intermediate: global___CertChain.NoiseCertificate | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["intermediate", b"intermediate", "leaf", b"leaf"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["intermediate", b"intermediate", "leaf", b"leaf"]) -> None: ...

global___CertChain = CertChain
