# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waArmadilloApplication/WAArmadilloApplication.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waArmadilloApplication/WAArmadilloApplication.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waArmadilloXMA import WAArmadilloXMA_pb2 as waArmadilloXMA_dot_WAArmadilloXMA__pb2
from waCommon import WACommon_pb2 as waCommon_dot_WACommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3waArmadilloApplication/WAArmadilloApplication.proto\x12\x16WAArmadilloApplication\x1a#waArmadilloXMA/WAArmadilloXMA.proto\x1a\x17waCommon/WACommon.proto\"\xd9\x35\n\tArmadillo\x12:\n\x07payload\x18\x01 \x01(\x0b\x32).WAArmadilloApplication.Armadillo.Payload\x12<\n\x08metadata\x18\x02 \x01(\x0b\x32*.WAArmadilloApplication.Armadillo.Metadata\x1a\n\n\x08Metadata\x1a\xa9\x02\n\x07Payload\x12<\n\x07\x63ontent\x18\x01 \x01(\x0b\x32).WAArmadilloApplication.Armadillo.ContentH\x00\x12L\n\x0f\x61pplicationData\x18\x02 \x01(\x0b\x32\x31.WAArmadilloApplication.Armadillo.ApplicationDataH\x00\x12:\n\x06signal\x18\x03 \x01(\x0b\x32(.WAArmadilloApplication.Armadillo.SignalH\x00\x12K\n\x0bsubProtocol\x18\x04 \x01(\x0b\x32\x34.WAArmadilloApplication.Armadillo.SubProtocolPayloadH\x00\x42\t\n\x07payload\x1aH\n\x12SubProtocolPayload\x12\x32\n\x0b\x66utureProof\x18\x01 \x01(\x0e\x32\x1d.WACommon.FutureProofBehavior\x1a\xae\x04\n\x06Signal\x12\x63\n\x17\x65ncryptedBackupsSecrets\x18\x01 \x01(\x0b\x32@.WAArmadilloApplication.Armadillo.Signal.EncryptedBackupsSecretsH\x00\x1a\xb4\x03\n\x17\x45ncryptedBackupsSecrets\x12\x10\n\x08\x62\x61\x63kupID\x18\x01 \x01(\x04\x12\x14\n\x0cserverDataID\x18\x02 \x01(\x04\x12U\n\x05\x65poch\x18\x03 \x03(\x0b\x32\x46.WAArmadilloApplication.Armadillo.Signal.EncryptedBackupsSecrets.Epoch\x12\x1b\n\x13tempOcmfClientState\x18\x04 \x01(\x0c\x12\x16\n\x0emailboxRootKey\x18\x05 \x01(\x0c\x12 \n\x18obliviousValidationToken\x18\x06 \x01(\x0c\x1a\xc2\x01\n\x05\x45poch\x12\n\n\x02ID\x18\x01 \x01(\x04\x12\x0e\n\x06\x61nonID\x18\x02 \x01(\x0c\x12\x0f\n\x07rootKey\x18\x03 \x01(\x0c\x12\x62\n\x06status\x18\x04 \x01(\x0e\x32R.WAArmadilloApplication.Armadillo.Signal.EncryptedBackupsSecrets.Epoch.EpochStatus\"(\n\x0b\x45pochStatus\x12\x0b\n\x07\x45S_OPEN\x10\x01\x12\x0c\n\x08\x45S_CLOSE\x10\x02\x42\x08\n\x06signal\x1a\xde\x11\n\x0f\x41pplicationData\x12\x62\n\x0cmetadataSync\x18\x01 \x01(\x0b\x32J.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncNotificationH\x00\x12_\n\raiBotResponse\x18\x02 \x01(\x0b\x32\x46.WAArmadilloApplication.Armadillo.ApplicationData.AIBotResponseMessageH\x00\x12x\n\x1dmessageHistoryDocumentMessage\x18\x03 \x01(\x0b\x32O.WAArmadilloApplication.Armadillo.ApplicationData.MessageHistoryDocumentMessageH\x00\x1aH\n\x1dMessageHistoryDocumentMessage\x12\'\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocol\x1aZ\n\x14\x41IBotResponseMessage\x12\x13\n\x0bsummonToken\x18\x01 \x01(\t\x12\x13\n\x0bmessageText\x18\x02 \x01(\t\x12\x18\n\x10serializedExtras\x18\x03 \x01(\t\x1a\xdf\x0c\n\x12MetadataSyncAction\x12i\n\nchatAction\x18\x65 \x01(\x0b\x32S.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncChatActionH\x00\x12o\n\rmessageAction\x18\x66 \x01(\x0b\x32V.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncMessageActionH\x00\x12\x17\n\x0f\x61\x63tionTimestamp\x18\x01 \x01(\x03\x1a\xdd\x01\n\x11SyncMessageAction\x12\x83\x01\n\rmessageDelete\x18\x65 \x01(\x0b\x32j.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncMessageAction.ActionMessageDeleteH\x00\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x1a\x15\n\x13\x41\x63tionMessageDeleteB\x08\n\x06\x61\x63tion\x1a\xd3\x06\n\x0eSyncChatAction\x12|\n\x0b\x63hatArchive\x18\x65 \x01(\x0b\x32\x65.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatArchiveH\x00\x12z\n\nchatDelete\x18\x66 \x01(\x0b\x32\x64.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatDeleteH\x00\x12v\n\x08\x63hatRead\x18g \x01(\x0b\x32\x62.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatReadH\x00\x12\x0e\n\x06\x63hatID\x18\x01 \x01(\t\x1a\x91\x01\n\x0e\x41\x63tionChatRead\x12q\n\x0cmessageRange\x18\x01 \x01(\x0b\x32[.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange\x12\x0c\n\x04read\x18\x02 \x01(\x08\x1a\x85\x01\n\x10\x41\x63tionChatDelete\x12q\n\x0cmessageRange\x18\x01 \x01(\x0b\x32[.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange\x1a\x98\x01\n\x11\x41\x63tionChatArchive\x12q\n\x0cmessageRange\x18\x01 \x01(\x0b\x32[.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange\x12\x10\n\x08\x61rchived\x18\x02 \x01(\x08\x42\x08\n\x06\x61\x63tion\x1aI\n\x11SyncActionMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x1a\xc4\x01\n\x16SyncActionMessageRange\x12\x1c\n\x14lastMessageTimestamp\x18\x01 \x01(\x03\x12\"\n\x1alastSystemMessageTimestamp\x18\x02 \x01(\x03\x12h\n\x08messages\x18\x03 \x03(\x0b\x32V.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageB\x0c\n\nactionType\x1aq\n\x18MetadataSyncNotification\x12U\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32\x44.WAArmadilloApplication.Armadillo.ApplicationData.MetadataSyncActionB\x11\n\x0f\x61pplicationData\x1a\xbd\x1b\n\x07\x43ontent\x12P\n\rcommonSticker\x18\x01 \x01(\x0b\x32\x37.WAArmadilloApplication.Armadillo.Content.CommonStickerH\x00\x12V\n\x10screenshotAction\x18\x03 \x01(\x0b\x32:.WAArmadilloApplication.Armadillo.Content.ScreenshotActionH\x00\x12H\n\x16\x65xtendedContentMessage\x18\x04 \x01(\x0b\x32&.WAArmadilloXMA.ExtendedContentMessageH\x00\x12N\n\x0cravenMessage\x18\x05 \x01(\x0b\x32\x36.WAArmadilloApplication.Armadillo.Content.RavenMessageH\x00\x12\x64\n\x17ravenActionNotifMessage\x18\x06 \x01(\x0b\x32\x41.WAArmadilloApplication.Armadillo.Content.RavenActionNotifMessageH\x00\x12r\n\x1e\x65xtendedMessageContentWithSear\x18\x07 \x01(\x0b\x32H.WAArmadilloApplication.Armadillo.Content.ExtendedContentMessageWithSearH\x00\x12\\\n\x13imageGalleryMessage\x18\x08 \x01(\x0b\x32=.WAArmadilloApplication.Armadillo.Content.ImageGalleryMessageH\x00\x12j\n\x1apaymentsTransactionMessage\x18\n \x01(\x0b\x32\x44.WAArmadilloApplication.Armadillo.Content.PaymentsTransactionMessageH\x00\x12\\\n\x13\x62umpExistingMessage\x18\x0b \x01(\x0b\x32=.WAArmadilloApplication.Armadillo.Content.BumpExistingMessageH\x00\x12V\n\x10noteReplyMessage\x18\r \x01(\x0b\x32:.WAArmadilloApplication.Armadillo.Content.NoteReplyMessageH\x00\x12R\n\x10ravenMessageMsgr\x18\x0e \x01(\x0b\x32\x36.WAArmadilloApplication.Armadillo.Content.RavenMessageH\x00\x12j\n\x1anetworkVerificationMessage\x18\x0f \x01(\x0b\x32\x44.WAArmadilloApplication.Armadillo.Content.NetworkVerificationMessageH\x00\x1a\xf2\x06\n\x1aPaymentsTransactionMessage\x12\x15\n\rtransactionID\x18\x01 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\x12\x10\n\x08\x63urrency\x18\x03 \x01(\t\x12i\n\rpaymentStatus\x18\x04 \x01(\x0e\x32R.WAArmadilloApplication.Armadillo.Content.PaymentsTransactionMessage.PaymentStatus\x12\x46\n\x16\x65xtendedContentMessage\x18\x05 \x01(\x0b\x32&.WAArmadilloXMA.ExtendedContentMessage\"\xe7\x04\n\rPaymentStatus\x12\x13\n\x0fPAYMENT_UNKNOWN\x10\x00\x12\x12\n\x0eREQUEST_INITED\x10\x04\x12\x14\n\x10REQUEST_DECLINED\x10\x05\x12\x1b\n\x17REQUEST_TRANSFER_INITED\x10\x06\x12\x1e\n\x1aREQUEST_TRANSFER_COMPLETED\x10\x07\x12\x1b\n\x17REQUEST_TRANSFER_FAILED\x10\x08\x12\x14\n\x10REQUEST_CANCELED\x10\t\x12\x13\n\x0fREQUEST_EXPIRED\x10\n\x12\x13\n\x0fTRANSFER_INITED\x10\x0b\x12\x14\n\x10TRANSFER_PENDING\x10\x0c\x12+\n\'TRANSFER_PENDING_RECIPIENT_VERIFICATION\x10\r\x12\x15\n\x11TRANSFER_CANCELED\x10\x0e\x12\x16\n\x12TRANSFER_COMPLETED\x10\x0f\x12;\n7TRANSFER_NO_RECEIVER_CREDENTIAL_NO_RTS_PENDING_CANCELED\x10\x10\x12\x38\n4TRANSFER_NO_RECEIVER_CREDENTIAL_NO_RTS_PENDING_OTHER\x10\x11\x12\x15\n\x11TRANSFER_REFUNDED\x10\x12\x12\x1b\n\x17TRANSFER_PARTIAL_REFUND\x10\x13\x12\x19\n\x15TRANSFER_CHARGED_BACK\x10\x14\x12\x14\n\x10TRANSFER_EXPIRED\x10\x15\x12\x15\n\x11TRANSFER_DECLINED\x10\x16\x12\x18\n\x14TRANSFER_UNAVAILABLE\x10\x17\x1a.\n\x1aNetworkVerificationMessage\x12\x10\n\x08\x63odeText\x18\x01 \x01(\t\x1a\x86\x02\n\x10NoteReplyMessage\x12,\n\x0btextContent\x18\x04 \x01(\x0b\x32\x15.WACommon.MessageTextH\x00\x12/\n\x0estickerContent\x18\x05 \x01(\x0b\x32\x15.WACommon.SubProtocolH\x00\x12-\n\x0cvideoContent\x18\x06 \x01(\x0b\x32\x15.WACommon.SubProtocolH\x00\x12\x0e\n\x06noteID\x18\x01 \x01(\t\x12\'\n\x08noteText\x18\x02 \x01(\x0b\x32\x15.WACommon.MessageText\x12\x17\n\x0fnoteTimestampMS\x18\x03 \x01(\x03\x42\x12\n\x10noteReplyContent\x1a\x38\n\x13\x42umpExistingMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x1a<\n\x13ImageGalleryMessage\x12%\n\x06images\x18\x01 \x03(\x0b\x32\x15.WACommon.SubProtocol\x1a\xb3\x01\n\x10ScreenshotAction\x12\x61\n\x0escreenshotType\x18\x01 \x01(\x0e\x32I.WAArmadilloApplication.Armadillo.Content.ScreenshotAction.ScreenshotType\"<\n\x0eScreenshotType\x12\x14\n\x10SCREENSHOT_IMAGE\x10\x01\x12\x14\n\x10SCREEN_RECORDING\x10\x02\x1a\xa9\x01\n\x1e\x45xtendedContentMessageWithSear\x12\x0e\n\x06searID\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x11\n\tnativeURL\x18\x03 \x01(\t\x12\x34\n\x15searAssociatedMessage\x18\x04 \x01(\x0b\x32\x15.WACommon.SubProtocol\x12\x1d\n\x15searSentWithMessageID\x18\x05 \x01(\t\x1a\xf4\x01\n\x17RavenActionNotifMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x17\n\x0f\x61\x63tionTimestamp\x18\x02 \x01(\x03\x12`\n\nactionType\x18\x03 \x01(\x0e\x32L.WAArmadilloApplication.Armadillo.Content.RavenActionNotifMessage.ActionType\";\n\nActionType\x12\n\n\x06PLAYED\x10\x00\x12\x0e\n\nSCREENSHOT\x10\x01\x12\x11\n\rFORCE_DISABLE\x10\x02\x1a\x9d\x02\n\x0cRavenMessage\x12-\n\x0cimageMessage\x18\x02 \x01(\x0b\x32\x15.WACommon.SubProtocolH\x00\x12-\n\x0cvideoMessage\x18\x03 \x01(\x0b\x32\x15.WACommon.SubProtocolH\x00\x12[\n\rephemeralType\x18\x01 \x01(\x0e\x32\x44.WAArmadilloApplication.Armadillo.Content.RavenMessage.EphemeralType\"B\n\rEphemeralType\x12\r\n\tVIEW_ONCE\x10\x00\x12\x10\n\x0c\x41LLOW_REPLAY\x10\x01\x12\x10\n\x0cKEEP_IN_CHAT\x10\x02\x42\x0e\n\x0cmediaContent\x1a\xa9\x01\n\rCommonSticker\x12X\n\x0bstickerType\x18\x01 \x01(\x0e\x32\x43.WAArmadilloApplication.Armadillo.Content.CommonSticker.StickerType\">\n\x0bStickerType\x12\x0e\n\nSMALL_LIKE\x10\x01\x12\x0f\n\x0bMEDIUM_LIKE\x10\x02\x12\x0e\n\nLARGE_LIKE\x10\x03\x42\t\n\x07\x63ontentB2Z0go.mau.fi/whatsmeow/proto/waArmadilloApplication')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waArmadilloApplication.WAArmadilloApplication_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0go.mau.fi/whatsmeow/proto/waArmadilloApplication'
  _globals['_ARMADILLO']._serialized_start=142
  _globals['_ARMADILLO']._serialized_end=7015
  _globals['_ARMADILLO_METADATA']._serialized_start=277
  _globals['_ARMADILLO_METADATA']._serialized_end=287
  _globals['_ARMADILLO_PAYLOAD']._serialized_start=290
  _globals['_ARMADILLO_PAYLOAD']._serialized_end=587
  _globals['_ARMADILLO_SUBPROTOCOLPAYLOAD']._serialized_start=589
  _globals['_ARMADILLO_SUBPROTOCOLPAYLOAD']._serialized_end=661
  _globals['_ARMADILLO_SIGNAL']._serialized_start=664
  _globals['_ARMADILLO_SIGNAL']._serialized_end=1222
  _globals['_ARMADILLO_SIGNAL_ENCRYPTEDBACKUPSSECRETS']._serialized_start=776
  _globals['_ARMADILLO_SIGNAL_ENCRYPTEDBACKUPSSECRETS']._serialized_end=1212
  _globals['_ARMADILLO_SIGNAL_ENCRYPTEDBACKUPSSECRETS_EPOCH']._serialized_start=1018
  _globals['_ARMADILLO_SIGNAL_ENCRYPTEDBACKUPSSECRETS_EPOCH']._serialized_end=1212
  _globals['_ARMADILLO_SIGNAL_ENCRYPTEDBACKUPSSECRETS_EPOCH_EPOCHSTATUS']._serialized_start=1172
  _globals['_ARMADILLO_SIGNAL_ENCRYPTEDBACKUPSSECRETS_EPOCH_EPOCHSTATUS']._serialized_end=1212
  _globals['_ARMADILLO_APPLICATIONDATA']._serialized_start=1225
  _globals['_ARMADILLO_APPLICATIONDATA']._serialized_end=3495
  _globals['_ARMADILLO_APPLICATIONDATA_MESSAGEHISTORYDOCUMENTMESSAGE']._serialized_start=1563
  _globals['_ARMADILLO_APPLICATIONDATA_MESSAGEHISTORYDOCUMENTMESSAGE']._serialized_end=1635
  _globals['_ARMADILLO_APPLICATIONDATA_AIBOTRESPONSEMESSAGE']._serialized_start=1637
  _globals['_ARMADILLO_APPLICATIONDATA_AIBOTRESPONSEMESSAGE']._serialized_end=1727
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION']._serialized_start=1730
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION']._serialized_end=3361
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCMESSAGEACTION']._serialized_start=1998
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCMESSAGEACTION']._serialized_end=2219
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCMESSAGEACTION_ACTIONMESSAGEDELETE']._serialized_start=2188
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCMESSAGEACTION_ACTIONMESSAGEDELETE']._serialized_end=2209
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCCHATACTION']._serialized_start=2222
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCCHATACTION']._serialized_end=3073
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCCHATACTION_ACTIONCHATREAD']._serialized_start=2627
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCCHATACTION_ACTIONCHATREAD']._serialized_end=2772
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCCHATACTION_ACTIONCHATDELETE']._serialized_start=2775
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCCHATACTION_ACTIONCHATDELETE']._serialized_end=2908
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCCHATACTION_ACTIONCHATARCHIVE']._serialized_start=2911
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCCHATACTION_ACTIONCHATARCHIVE']._serialized_end=3063
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCACTIONMESSAGE']._serialized_start=3075
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCACTIONMESSAGE']._serialized_end=3148
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCACTIONMESSAGERANGE']._serialized_start=3151
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCACTION_SYNCACTIONMESSAGERANGE']._serialized_end=3347
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCNOTIFICATION']._serialized_start=3363
  _globals['_ARMADILLO_APPLICATIONDATA_METADATASYNCNOTIFICATION']._serialized_end=3476
  _globals['_ARMADILLO_CONTENT']._serialized_start=3498
  _globals['_ARMADILLO_CONTENT']._serialized_end=7015
  _globals['_ARMADILLO_CONTENT_PAYMENTSTRANSACTIONMESSAGE']._serialized_start=4628
  _globals['_ARMADILLO_CONTENT_PAYMENTSTRANSACTIONMESSAGE']._serialized_end=5510
  _globals['_ARMADILLO_CONTENT_PAYMENTSTRANSACTIONMESSAGE_PAYMENTSTATUS']._serialized_start=4895
  _globals['_ARMADILLO_CONTENT_PAYMENTSTRANSACTIONMESSAGE_PAYMENTSTATUS']._serialized_end=5510
  _globals['_ARMADILLO_CONTENT_NETWORKVERIFICATIONMESSAGE']._serialized_start=5512
  _globals['_ARMADILLO_CONTENT_NETWORKVERIFICATIONMESSAGE']._serialized_end=5558
  _globals['_ARMADILLO_CONTENT_NOTEREPLYMESSAGE']._serialized_start=5561
  _globals['_ARMADILLO_CONTENT_NOTEREPLYMESSAGE']._serialized_end=5823
  _globals['_ARMADILLO_CONTENT_BUMPEXISTINGMESSAGE']._serialized_start=5825
  _globals['_ARMADILLO_CONTENT_BUMPEXISTINGMESSAGE']._serialized_end=5881
  _globals['_ARMADILLO_CONTENT_IMAGEGALLERYMESSAGE']._serialized_start=5883
  _globals['_ARMADILLO_CONTENT_IMAGEGALLERYMESSAGE']._serialized_end=5943
  _globals['_ARMADILLO_CONTENT_SCREENSHOTACTION']._serialized_start=5946
  _globals['_ARMADILLO_CONTENT_SCREENSHOTACTION']._serialized_end=6125
  _globals['_ARMADILLO_CONTENT_SCREENSHOTACTION_SCREENSHOTTYPE']._serialized_start=6065
  _globals['_ARMADILLO_CONTENT_SCREENSHOTACTION_SCREENSHOTTYPE']._serialized_end=6125
  _globals['_ARMADILLO_CONTENT_EXTENDEDCONTENTMESSAGEWITHSEAR']._serialized_start=6128
  _globals['_ARMADILLO_CONTENT_EXTENDEDCONTENTMESSAGEWITHSEAR']._serialized_end=6297
  _globals['_ARMADILLO_CONTENT_RAVENACTIONNOTIFMESSAGE']._serialized_start=6300
  _globals['_ARMADILLO_CONTENT_RAVENACTIONNOTIFMESSAGE']._serialized_end=6544
  _globals['_ARMADILLO_CONTENT_RAVENACTIONNOTIFMESSAGE_ACTIONTYPE']._serialized_start=6485
  _globals['_ARMADILLO_CONTENT_RAVENACTIONNOTIFMESSAGE_ACTIONTYPE']._serialized_end=6544
  _globals['_ARMADILLO_CONTENT_RAVENMESSAGE']._serialized_start=6547
  _globals['_ARMADILLO_CONTENT_RAVENMESSAGE']._serialized_end=6832
  _globals['_ARMADILLO_CONTENT_RAVENMESSAGE_EPHEMERALTYPE']._serialized_start=6750
  _globals['_ARMADILLO_CONTENT_RAVENMESSAGE_EPHEMERALTYPE']._serialized_end=6816
  _globals['_ARMADILLO_CONTENT_COMMONSTICKER']._serialized_start=6835
  _globals['_ARMADILLO_CONTENT_COMMONSTICKER']._serialized_end=7004
  _globals['_ARMADILLO_CONTENT_COMMONSTICKER_STICKERTYPE']._serialized_start=6942
  _globals['_ARMADILLO_CONTENT_COMMONSTICKER_STICKERTYPE']._serialized_end=7004
# @@protoc_insertion_point(module_scope)
