"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import waArmadilloXMA.WAArmadilloXMA_pb2
import waCommon.WACommon_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Armadillo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Metadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class Payload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CONTENT_FIELD_NUMBER: builtins.int
        APPLICATIONDATA_FIELD_NUMBER: builtins.int
        SIGNAL_FIELD_NUMBER: builtins.int
        SUBPROTOCOL_FIELD_NUMBER: builtins.int
        @property
        def content(self) -> global___Armadillo.Content: ...
        @property
        def applicationData(self) -> global___Armadillo.ApplicationData: ...
        @property
        def signal(self) -> global___Armadillo.Signal: ...
        @property
        def subProtocol(self) -> global___Armadillo.SubProtocolPayload: ...
        def __init__(
            self,
            *,
            content: global___Armadillo.Content | None = ...,
            applicationData: global___Armadillo.ApplicationData | None = ...,
            signal: global___Armadillo.Signal | None = ...,
            subProtocol: global___Armadillo.SubProtocolPayload | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["applicationData", b"applicationData", "content", b"content", "payload", b"payload", "signal", b"signal", "subProtocol", b"subProtocol"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["applicationData", b"applicationData", "content", b"content", "payload", b"payload", "signal", b"signal", "subProtocol", b"subProtocol"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["payload", b"payload"]) -> typing.Literal["content", "applicationData", "signal", "subProtocol"] | None: ...

    @typing.final
    class SubProtocolPayload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FUTUREPROOF_FIELD_NUMBER: builtins.int
        futureProof: waCommon.WACommon_pb2.FutureProofBehavior.ValueType
        def __init__(
            self,
            *,
            futureProof: waCommon.WACommon_pb2.FutureProofBehavior.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["futureProof", b"futureProof"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["futureProof", b"futureProof"]) -> None: ...

    @typing.final
    class Signal(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class EncryptedBackupsSecrets(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            @typing.final
            class Epoch(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                class _EpochStatus:
                    ValueType = typing.NewType("ValueType", builtins.int)
                    V: typing_extensions.TypeAlias = ValueType

                class _EpochStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Armadillo.Signal.EncryptedBackupsSecrets.Epoch._EpochStatus.ValueType], builtins.type):
                    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                    ES_OPEN: Armadillo.Signal.EncryptedBackupsSecrets.Epoch._EpochStatus.ValueType  # 1
                    ES_CLOSE: Armadillo.Signal.EncryptedBackupsSecrets.Epoch._EpochStatus.ValueType  # 2

                class EpochStatus(_EpochStatus, metaclass=_EpochStatusEnumTypeWrapper): ...
                ES_OPEN: Armadillo.Signal.EncryptedBackupsSecrets.Epoch.EpochStatus.ValueType  # 1
                ES_CLOSE: Armadillo.Signal.EncryptedBackupsSecrets.Epoch.EpochStatus.ValueType  # 2

                ID_FIELD_NUMBER: builtins.int
                ANONID_FIELD_NUMBER: builtins.int
                ROOTKEY_FIELD_NUMBER: builtins.int
                STATUS_FIELD_NUMBER: builtins.int
                ID: builtins.int
                anonID: builtins.bytes
                rootKey: builtins.bytes
                status: global___Armadillo.Signal.EncryptedBackupsSecrets.Epoch.EpochStatus.ValueType
                def __init__(
                    self,
                    *,
                    ID: builtins.int | None = ...,
                    anonID: builtins.bytes | None = ...,
                    rootKey: builtins.bytes | None = ...,
                    status: global___Armadillo.Signal.EncryptedBackupsSecrets.Epoch.EpochStatus.ValueType | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["ID", b"ID", "anonID", b"anonID", "rootKey", b"rootKey", "status", b"status"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["ID", b"ID", "anonID", b"anonID", "rootKey", b"rootKey", "status", b"status"]) -> None: ...

            BACKUPID_FIELD_NUMBER: builtins.int
            SERVERDATAID_FIELD_NUMBER: builtins.int
            EPOCH_FIELD_NUMBER: builtins.int
            TEMPOCMFCLIENTSTATE_FIELD_NUMBER: builtins.int
            MAILBOXROOTKEY_FIELD_NUMBER: builtins.int
            OBLIVIOUSVALIDATIONTOKEN_FIELD_NUMBER: builtins.int
            backupID: builtins.int
            serverDataID: builtins.int
            tempOcmfClientState: builtins.bytes
            mailboxRootKey: builtins.bytes
            obliviousValidationToken: builtins.bytes
            @property
            def epoch(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Armadillo.Signal.EncryptedBackupsSecrets.Epoch]: ...
            def __init__(
                self,
                *,
                backupID: builtins.int | None = ...,
                serverDataID: builtins.int | None = ...,
                epoch: collections.abc.Iterable[global___Armadillo.Signal.EncryptedBackupsSecrets.Epoch] | None = ...,
                tempOcmfClientState: builtins.bytes | None = ...,
                mailboxRootKey: builtins.bytes | None = ...,
                obliviousValidationToken: builtins.bytes | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["backupID", b"backupID", "mailboxRootKey", b"mailboxRootKey", "obliviousValidationToken", b"obliviousValidationToken", "serverDataID", b"serverDataID", "tempOcmfClientState", b"tempOcmfClientState"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["backupID", b"backupID", "epoch", b"epoch", "mailboxRootKey", b"mailboxRootKey", "obliviousValidationToken", b"obliviousValidationToken", "serverDataID", b"serverDataID", "tempOcmfClientState", b"tempOcmfClientState"]) -> None: ...

        ENCRYPTEDBACKUPSSECRETS_FIELD_NUMBER: builtins.int
        @property
        def encryptedBackupsSecrets(self) -> global___Armadillo.Signal.EncryptedBackupsSecrets: ...
        def __init__(
            self,
            *,
            encryptedBackupsSecrets: global___Armadillo.Signal.EncryptedBackupsSecrets | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["encryptedBackupsSecrets", b"encryptedBackupsSecrets", "signal", b"signal"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["encryptedBackupsSecrets", b"encryptedBackupsSecrets", "signal", b"signal"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["signal", b"signal"]) -> typing.Literal["encryptedBackupsSecrets"] | None: ...

    @typing.final
    class ApplicationData(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class MessageHistoryDocumentMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            DOCUMENT_FIELD_NUMBER: builtins.int
            @property
            def document(self) -> waCommon.WACommon_pb2.SubProtocol: ...
            def __init__(
                self,
                *,
                document: waCommon.WACommon_pb2.SubProtocol | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["document", b"document"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["document", b"document"]) -> None: ...

        @typing.final
        class AIBotResponseMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            SUMMONTOKEN_FIELD_NUMBER: builtins.int
            MESSAGETEXT_FIELD_NUMBER: builtins.int
            SERIALIZEDEXTRAS_FIELD_NUMBER: builtins.int
            summonToken: builtins.str
            messageText: builtins.str
            serializedExtras: builtins.str
            def __init__(
                self,
                *,
                summonToken: builtins.str | None = ...,
                messageText: builtins.str | None = ...,
                serializedExtras: builtins.str | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["messageText", b"messageText", "serializedExtras", b"serializedExtras", "summonToken", b"summonToken"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["messageText", b"messageText", "serializedExtras", b"serializedExtras", "summonToken", b"summonToken"]) -> None: ...

        @typing.final
        class MetadataSyncAction(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            @typing.final
            class SyncMessageAction(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                @typing.final
                class ActionMessageDelete(google.protobuf.message.Message):
                    DESCRIPTOR: google.protobuf.descriptor.Descriptor

                    def __init__(
                        self,
                    ) -> None: ...

                MESSAGEDELETE_FIELD_NUMBER: builtins.int
                KEY_FIELD_NUMBER: builtins.int
                @property
                def messageDelete(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncMessageAction.ActionMessageDelete: ...
                @property
                def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
                def __init__(
                    self,
                    *,
                    messageDelete: global___Armadillo.ApplicationData.MetadataSyncAction.SyncMessageAction.ActionMessageDelete | None = ...,
                    key: waCommon.WACommon_pb2.MessageKey | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["action", b"action", "key", b"key", "messageDelete", b"messageDelete"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["action", b"action", "key", b"key", "messageDelete", b"messageDelete"]) -> None: ...
                def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["messageDelete"] | None: ...

            @typing.final
            class SyncChatAction(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                @typing.final
                class ActionChatRead(google.protobuf.message.Message):
                    DESCRIPTOR: google.protobuf.descriptor.Descriptor

                    MESSAGERANGE_FIELD_NUMBER: builtins.int
                    READ_FIELD_NUMBER: builtins.int
                    read: builtins.bool
                    @property
                    def messageRange(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange: ...
                    def __init__(
                        self,
                        *,
                        messageRange: global___Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange | None = ...,
                        read: builtins.bool | None = ...,
                    ) -> None: ...
                    def HasField(self, field_name: typing.Literal["messageRange", b"messageRange", "read", b"read"]) -> builtins.bool: ...
                    def ClearField(self, field_name: typing.Literal["messageRange", b"messageRange", "read", b"read"]) -> None: ...

                @typing.final
                class ActionChatDelete(google.protobuf.message.Message):
                    DESCRIPTOR: google.protobuf.descriptor.Descriptor

                    MESSAGERANGE_FIELD_NUMBER: builtins.int
                    @property
                    def messageRange(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange: ...
                    def __init__(
                        self,
                        *,
                        messageRange: global___Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange | None = ...,
                    ) -> None: ...
                    def HasField(self, field_name: typing.Literal["messageRange", b"messageRange"]) -> builtins.bool: ...
                    def ClearField(self, field_name: typing.Literal["messageRange", b"messageRange"]) -> None: ...

                @typing.final
                class ActionChatArchive(google.protobuf.message.Message):
                    DESCRIPTOR: google.protobuf.descriptor.Descriptor

                    MESSAGERANGE_FIELD_NUMBER: builtins.int
                    ARCHIVED_FIELD_NUMBER: builtins.int
                    archived: builtins.bool
                    @property
                    def messageRange(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange: ...
                    def __init__(
                        self,
                        *,
                        messageRange: global___Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessageRange | None = ...,
                        archived: builtins.bool | None = ...,
                    ) -> None: ...
                    def HasField(self, field_name: typing.Literal["archived", b"archived", "messageRange", b"messageRange"]) -> builtins.bool: ...
                    def ClearField(self, field_name: typing.Literal["archived", b"archived", "messageRange", b"messageRange"]) -> None: ...

                CHATARCHIVE_FIELD_NUMBER: builtins.int
                CHATDELETE_FIELD_NUMBER: builtins.int
                CHATREAD_FIELD_NUMBER: builtins.int
                CHATID_FIELD_NUMBER: builtins.int
                chatID: builtins.str
                @property
                def chatArchive(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatArchive: ...
                @property
                def chatDelete(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatDelete: ...
                @property
                def chatRead(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatRead: ...
                def __init__(
                    self,
                    *,
                    chatArchive: global___Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatArchive | None = ...,
                    chatDelete: global___Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatDelete | None = ...,
                    chatRead: global___Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction.ActionChatRead | None = ...,
                    chatID: builtins.str | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["action", b"action", "chatArchive", b"chatArchive", "chatDelete", b"chatDelete", "chatID", b"chatID", "chatRead", b"chatRead"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["action", b"action", "chatArchive", b"chatArchive", "chatDelete", b"chatDelete", "chatID", b"chatID", "chatRead", b"chatRead"]) -> None: ...
                def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["chatArchive", "chatDelete", "chatRead"] | None: ...

            @typing.final
            class SyncActionMessage(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                KEY_FIELD_NUMBER: builtins.int
                TIMESTAMP_FIELD_NUMBER: builtins.int
                timestamp: builtins.int
                @property
                def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
                def __init__(
                    self,
                    *,
                    key: waCommon.WACommon_pb2.MessageKey | None = ...,
                    timestamp: builtins.int | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["key", b"key", "timestamp", b"timestamp"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["key", b"key", "timestamp", b"timestamp"]) -> None: ...

            @typing.final
            class SyncActionMessageRange(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                LASTMESSAGETIMESTAMP_FIELD_NUMBER: builtins.int
                LASTSYSTEMMESSAGETIMESTAMP_FIELD_NUMBER: builtins.int
                MESSAGES_FIELD_NUMBER: builtins.int
                lastMessageTimestamp: builtins.int
                lastSystemMessageTimestamp: builtins.int
                @property
                def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessage]: ...
                def __init__(
                    self,
                    *,
                    lastMessageTimestamp: builtins.int | None = ...,
                    lastSystemMessageTimestamp: builtins.int | None = ...,
                    messages: collections.abc.Iterable[global___Armadillo.ApplicationData.MetadataSyncAction.SyncActionMessage] | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["lastMessageTimestamp", b"lastMessageTimestamp", "lastSystemMessageTimestamp", b"lastSystemMessageTimestamp"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["lastMessageTimestamp", b"lastMessageTimestamp", "lastSystemMessageTimestamp", b"lastSystemMessageTimestamp", "messages", b"messages"]) -> None: ...

            CHATACTION_FIELD_NUMBER: builtins.int
            MESSAGEACTION_FIELD_NUMBER: builtins.int
            ACTIONTIMESTAMP_FIELD_NUMBER: builtins.int
            actionTimestamp: builtins.int
            @property
            def chatAction(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction: ...
            @property
            def messageAction(self) -> global___Armadillo.ApplicationData.MetadataSyncAction.SyncMessageAction: ...
            def __init__(
                self,
                *,
                chatAction: global___Armadillo.ApplicationData.MetadataSyncAction.SyncChatAction | None = ...,
                messageAction: global___Armadillo.ApplicationData.MetadataSyncAction.SyncMessageAction | None = ...,
                actionTimestamp: builtins.int | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["actionTimestamp", b"actionTimestamp", "actionType", b"actionType", "chatAction", b"chatAction", "messageAction", b"messageAction"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["actionTimestamp", b"actionTimestamp", "actionType", b"actionType", "chatAction", b"chatAction", "messageAction", b"messageAction"]) -> None: ...
            def WhichOneof(self, oneof_group: typing.Literal["actionType", b"actionType"]) -> typing.Literal["chatAction", "messageAction"] | None: ...

        @typing.final
        class MetadataSyncNotification(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            ACTIONS_FIELD_NUMBER: builtins.int
            @property
            def actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Armadillo.ApplicationData.MetadataSyncAction]: ...
            def __init__(
                self,
                *,
                actions: collections.abc.Iterable[global___Armadillo.ApplicationData.MetadataSyncAction] | None = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["actions", b"actions"]) -> None: ...

        METADATASYNC_FIELD_NUMBER: builtins.int
        AIBOTRESPONSE_FIELD_NUMBER: builtins.int
        MESSAGEHISTORYDOCUMENTMESSAGE_FIELD_NUMBER: builtins.int
        @property
        def metadataSync(self) -> global___Armadillo.ApplicationData.MetadataSyncNotification: ...
        @property
        def aiBotResponse(self) -> global___Armadillo.ApplicationData.AIBotResponseMessage: ...
        @property
        def messageHistoryDocumentMessage(self) -> global___Armadillo.ApplicationData.MessageHistoryDocumentMessage: ...
        def __init__(
            self,
            *,
            metadataSync: global___Armadillo.ApplicationData.MetadataSyncNotification | None = ...,
            aiBotResponse: global___Armadillo.ApplicationData.AIBotResponseMessage | None = ...,
            messageHistoryDocumentMessage: global___Armadillo.ApplicationData.MessageHistoryDocumentMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["aiBotResponse", b"aiBotResponse", "applicationData", b"applicationData", "messageHistoryDocumentMessage", b"messageHistoryDocumentMessage", "metadataSync", b"metadataSync"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["aiBotResponse", b"aiBotResponse", "applicationData", b"applicationData", "messageHistoryDocumentMessage", b"messageHistoryDocumentMessage", "metadataSync", b"metadataSync"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["applicationData", b"applicationData"]) -> typing.Literal["metadataSync", "aiBotResponse", "messageHistoryDocumentMessage"] | None: ...

    @typing.final
    class Content(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class PaymentsTransactionMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _PaymentStatus:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _PaymentStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                PAYMENT_UNKNOWN: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 0
                REQUEST_INITED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 4
                REQUEST_DECLINED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 5
                REQUEST_TRANSFER_INITED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 6
                REQUEST_TRANSFER_COMPLETED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 7
                REQUEST_TRANSFER_FAILED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 8
                REQUEST_CANCELED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 9
                REQUEST_EXPIRED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 10
                TRANSFER_INITED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 11
                TRANSFER_PENDING: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 12
                TRANSFER_PENDING_RECIPIENT_VERIFICATION: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 13
                TRANSFER_CANCELED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 14
                TRANSFER_COMPLETED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 15
                TRANSFER_NO_RECEIVER_CREDENTIAL_NO_RTS_PENDING_CANCELED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 16
                TRANSFER_NO_RECEIVER_CREDENTIAL_NO_RTS_PENDING_OTHER: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 17
                TRANSFER_REFUNDED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 18
                TRANSFER_PARTIAL_REFUND: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 19
                TRANSFER_CHARGED_BACK: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 20
                TRANSFER_EXPIRED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 21
                TRANSFER_DECLINED: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 22
                TRANSFER_UNAVAILABLE: Armadillo.Content.PaymentsTransactionMessage._PaymentStatus.ValueType  # 23

            class PaymentStatus(_PaymentStatus, metaclass=_PaymentStatusEnumTypeWrapper): ...
            PAYMENT_UNKNOWN: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 0
            REQUEST_INITED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 4
            REQUEST_DECLINED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 5
            REQUEST_TRANSFER_INITED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 6
            REQUEST_TRANSFER_COMPLETED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 7
            REQUEST_TRANSFER_FAILED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 8
            REQUEST_CANCELED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 9
            REQUEST_EXPIRED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 10
            TRANSFER_INITED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 11
            TRANSFER_PENDING: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 12
            TRANSFER_PENDING_RECIPIENT_VERIFICATION: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 13
            TRANSFER_CANCELED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 14
            TRANSFER_COMPLETED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 15
            TRANSFER_NO_RECEIVER_CREDENTIAL_NO_RTS_PENDING_CANCELED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 16
            TRANSFER_NO_RECEIVER_CREDENTIAL_NO_RTS_PENDING_OTHER: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 17
            TRANSFER_REFUNDED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 18
            TRANSFER_PARTIAL_REFUND: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 19
            TRANSFER_CHARGED_BACK: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 20
            TRANSFER_EXPIRED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 21
            TRANSFER_DECLINED: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 22
            TRANSFER_UNAVAILABLE: Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType  # 23

            TRANSACTIONID_FIELD_NUMBER: builtins.int
            AMOUNT_FIELD_NUMBER: builtins.int
            CURRENCY_FIELD_NUMBER: builtins.int
            PAYMENTSTATUS_FIELD_NUMBER: builtins.int
            EXTENDEDCONTENTMESSAGE_FIELD_NUMBER: builtins.int
            transactionID: builtins.int
            amount: builtins.str
            currency: builtins.str
            paymentStatus: global___Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType
            @property
            def extendedContentMessage(self) -> waArmadilloXMA.WAArmadilloXMA_pb2.ExtendedContentMessage: ...
            def __init__(
                self,
                *,
                transactionID: builtins.int | None = ...,
                amount: builtins.str | None = ...,
                currency: builtins.str | None = ...,
                paymentStatus: global___Armadillo.Content.PaymentsTransactionMessage.PaymentStatus.ValueType | None = ...,
                extendedContentMessage: waArmadilloXMA.WAArmadilloXMA_pb2.ExtendedContentMessage | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["amount", b"amount", "currency", b"currency", "extendedContentMessage", b"extendedContentMessage", "paymentStatus", b"paymentStatus", "transactionID", b"transactionID"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["amount", b"amount", "currency", b"currency", "extendedContentMessage", b"extendedContentMessage", "paymentStatus", b"paymentStatus", "transactionID", b"transactionID"]) -> None: ...

        @typing.final
        class NetworkVerificationMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            CODETEXT_FIELD_NUMBER: builtins.int
            codeText: builtins.str
            def __init__(
                self,
                *,
                codeText: builtins.str | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["codeText", b"codeText"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["codeText", b"codeText"]) -> None: ...

        @typing.final
        class NoteReplyMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            TEXTCONTENT_FIELD_NUMBER: builtins.int
            STICKERCONTENT_FIELD_NUMBER: builtins.int
            VIDEOCONTENT_FIELD_NUMBER: builtins.int
            NOTEID_FIELD_NUMBER: builtins.int
            NOTETEXT_FIELD_NUMBER: builtins.int
            NOTETIMESTAMPMS_FIELD_NUMBER: builtins.int
            noteID: builtins.str
            noteTimestampMS: builtins.int
            @property
            def textContent(self) -> waCommon.WACommon_pb2.MessageText: ...
            @property
            def stickerContent(self) -> waCommon.WACommon_pb2.SubProtocol: ...
            @property
            def videoContent(self) -> waCommon.WACommon_pb2.SubProtocol: ...
            @property
            def noteText(self) -> waCommon.WACommon_pb2.MessageText: ...
            def __init__(
                self,
                *,
                textContent: waCommon.WACommon_pb2.MessageText | None = ...,
                stickerContent: waCommon.WACommon_pb2.SubProtocol | None = ...,
                videoContent: waCommon.WACommon_pb2.SubProtocol | None = ...,
                noteID: builtins.str | None = ...,
                noteText: waCommon.WACommon_pb2.MessageText | None = ...,
                noteTimestampMS: builtins.int | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["noteID", b"noteID", "noteReplyContent", b"noteReplyContent", "noteText", b"noteText", "noteTimestampMS", b"noteTimestampMS", "stickerContent", b"stickerContent", "textContent", b"textContent", "videoContent", b"videoContent"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["noteID", b"noteID", "noteReplyContent", b"noteReplyContent", "noteText", b"noteText", "noteTimestampMS", b"noteTimestampMS", "stickerContent", b"stickerContent", "textContent", b"textContent", "videoContent", b"videoContent"]) -> None: ...
            def WhichOneof(self, oneof_group: typing.Literal["noteReplyContent", b"noteReplyContent"]) -> typing.Literal["textContent", "stickerContent", "videoContent"] | None: ...

        @typing.final
        class BumpExistingMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            @property
            def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
            def __init__(
                self,
                *,
                key: waCommon.WACommon_pb2.MessageKey | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["key", b"key"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["key", b"key"]) -> None: ...

        @typing.final
        class ImageGalleryMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            IMAGES_FIELD_NUMBER: builtins.int
            @property
            def images(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[waCommon.WACommon_pb2.SubProtocol]: ...
            def __init__(
                self,
                *,
                images: collections.abc.Iterable[waCommon.WACommon_pb2.SubProtocol] | None = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["images", b"images"]) -> None: ...

        @typing.final
        class ScreenshotAction(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _ScreenshotType:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _ScreenshotTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Armadillo.Content.ScreenshotAction._ScreenshotType.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                SCREENSHOT_IMAGE: Armadillo.Content.ScreenshotAction._ScreenshotType.ValueType  # 1
                SCREEN_RECORDING: Armadillo.Content.ScreenshotAction._ScreenshotType.ValueType  # 2

            class ScreenshotType(_ScreenshotType, metaclass=_ScreenshotTypeEnumTypeWrapper): ...
            SCREENSHOT_IMAGE: Armadillo.Content.ScreenshotAction.ScreenshotType.ValueType  # 1
            SCREEN_RECORDING: Armadillo.Content.ScreenshotAction.ScreenshotType.ValueType  # 2

            SCREENSHOTTYPE_FIELD_NUMBER: builtins.int
            screenshotType: global___Armadillo.Content.ScreenshotAction.ScreenshotType.ValueType
            def __init__(
                self,
                *,
                screenshotType: global___Armadillo.Content.ScreenshotAction.ScreenshotType.ValueType | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["screenshotType", b"screenshotType"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["screenshotType", b"screenshotType"]) -> None: ...

        @typing.final
        class ExtendedContentMessageWithSear(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            SEARID_FIELD_NUMBER: builtins.int
            PAYLOAD_FIELD_NUMBER: builtins.int
            NATIVEURL_FIELD_NUMBER: builtins.int
            SEARASSOCIATEDMESSAGE_FIELD_NUMBER: builtins.int
            SEARSENTWITHMESSAGEID_FIELD_NUMBER: builtins.int
            searID: builtins.str
            payload: builtins.bytes
            nativeURL: builtins.str
            searSentWithMessageID: builtins.str
            @property
            def searAssociatedMessage(self) -> waCommon.WACommon_pb2.SubProtocol: ...
            def __init__(
                self,
                *,
                searID: builtins.str | None = ...,
                payload: builtins.bytes | None = ...,
                nativeURL: builtins.str | None = ...,
                searAssociatedMessage: waCommon.WACommon_pb2.SubProtocol | None = ...,
                searSentWithMessageID: builtins.str | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["nativeURL", b"nativeURL", "payload", b"payload", "searAssociatedMessage", b"searAssociatedMessage", "searID", b"searID", "searSentWithMessageID", b"searSentWithMessageID"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["nativeURL", b"nativeURL", "payload", b"payload", "searAssociatedMessage", b"searAssociatedMessage", "searID", b"searID", "searSentWithMessageID", b"searSentWithMessageID"]) -> None: ...

        @typing.final
        class RavenActionNotifMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _ActionType:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _ActionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Armadillo.Content.RavenActionNotifMessage._ActionType.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                PLAYED: Armadillo.Content.RavenActionNotifMessage._ActionType.ValueType  # 0
                SCREENSHOT: Armadillo.Content.RavenActionNotifMessage._ActionType.ValueType  # 1
                FORCE_DISABLE: Armadillo.Content.RavenActionNotifMessage._ActionType.ValueType  # 2

            class ActionType(_ActionType, metaclass=_ActionTypeEnumTypeWrapper): ...
            PLAYED: Armadillo.Content.RavenActionNotifMessage.ActionType.ValueType  # 0
            SCREENSHOT: Armadillo.Content.RavenActionNotifMessage.ActionType.ValueType  # 1
            FORCE_DISABLE: Armadillo.Content.RavenActionNotifMessage.ActionType.ValueType  # 2

            KEY_FIELD_NUMBER: builtins.int
            ACTIONTIMESTAMP_FIELD_NUMBER: builtins.int
            ACTIONTYPE_FIELD_NUMBER: builtins.int
            actionTimestamp: builtins.int
            actionType: global___Armadillo.Content.RavenActionNotifMessage.ActionType.ValueType
            @property
            def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
            def __init__(
                self,
                *,
                key: waCommon.WACommon_pb2.MessageKey | None = ...,
                actionTimestamp: builtins.int | None = ...,
                actionType: global___Armadillo.Content.RavenActionNotifMessage.ActionType.ValueType | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["actionTimestamp", b"actionTimestamp", "actionType", b"actionType", "key", b"key"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["actionTimestamp", b"actionTimestamp", "actionType", b"actionType", "key", b"key"]) -> None: ...

        @typing.final
        class RavenMessage(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _EphemeralType:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _EphemeralTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Armadillo.Content.RavenMessage._EphemeralType.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                VIEW_ONCE: Armadillo.Content.RavenMessage._EphemeralType.ValueType  # 0
                ALLOW_REPLAY: Armadillo.Content.RavenMessage._EphemeralType.ValueType  # 1
                KEEP_IN_CHAT: Armadillo.Content.RavenMessage._EphemeralType.ValueType  # 2

            class EphemeralType(_EphemeralType, metaclass=_EphemeralTypeEnumTypeWrapper): ...
            VIEW_ONCE: Armadillo.Content.RavenMessage.EphemeralType.ValueType  # 0
            ALLOW_REPLAY: Armadillo.Content.RavenMessage.EphemeralType.ValueType  # 1
            KEEP_IN_CHAT: Armadillo.Content.RavenMessage.EphemeralType.ValueType  # 2

            IMAGEMESSAGE_FIELD_NUMBER: builtins.int
            VIDEOMESSAGE_FIELD_NUMBER: builtins.int
            EPHEMERALTYPE_FIELD_NUMBER: builtins.int
            ephemeralType: global___Armadillo.Content.RavenMessage.EphemeralType.ValueType
            @property
            def imageMessage(self) -> waCommon.WACommon_pb2.SubProtocol: ...
            @property
            def videoMessage(self) -> waCommon.WACommon_pb2.SubProtocol: ...
            def __init__(
                self,
                *,
                imageMessage: waCommon.WACommon_pb2.SubProtocol | None = ...,
                videoMessage: waCommon.WACommon_pb2.SubProtocol | None = ...,
                ephemeralType: global___Armadillo.Content.RavenMessage.EphemeralType.ValueType | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["ephemeralType", b"ephemeralType", "imageMessage", b"imageMessage", "mediaContent", b"mediaContent", "videoMessage", b"videoMessage"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["ephemeralType", b"ephemeralType", "imageMessage", b"imageMessage", "mediaContent", b"mediaContent", "videoMessage", b"videoMessage"]) -> None: ...
            def WhichOneof(self, oneof_group: typing.Literal["mediaContent", b"mediaContent"]) -> typing.Literal["imageMessage", "videoMessage"] | None: ...

        @typing.final
        class CommonSticker(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _StickerType:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _StickerTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Armadillo.Content.CommonSticker._StickerType.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                SMALL_LIKE: Armadillo.Content.CommonSticker._StickerType.ValueType  # 1
                MEDIUM_LIKE: Armadillo.Content.CommonSticker._StickerType.ValueType  # 2
                LARGE_LIKE: Armadillo.Content.CommonSticker._StickerType.ValueType  # 3

            class StickerType(_StickerType, metaclass=_StickerTypeEnumTypeWrapper): ...
            SMALL_LIKE: Armadillo.Content.CommonSticker.StickerType.ValueType  # 1
            MEDIUM_LIKE: Armadillo.Content.CommonSticker.StickerType.ValueType  # 2
            LARGE_LIKE: Armadillo.Content.CommonSticker.StickerType.ValueType  # 3

            STICKERTYPE_FIELD_NUMBER: builtins.int
            stickerType: global___Armadillo.Content.CommonSticker.StickerType.ValueType
            def __init__(
                self,
                *,
                stickerType: global___Armadillo.Content.CommonSticker.StickerType.ValueType | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["stickerType", b"stickerType"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["stickerType", b"stickerType"]) -> None: ...

        COMMONSTICKER_FIELD_NUMBER: builtins.int
        SCREENSHOTACTION_FIELD_NUMBER: builtins.int
        EXTENDEDCONTENTMESSAGE_FIELD_NUMBER: builtins.int
        RAVENMESSAGE_FIELD_NUMBER: builtins.int
        RAVENACTIONNOTIFMESSAGE_FIELD_NUMBER: builtins.int
        EXTENDEDMESSAGECONTENTWITHSEAR_FIELD_NUMBER: builtins.int
        IMAGEGALLERYMESSAGE_FIELD_NUMBER: builtins.int
        PAYMENTSTRANSACTIONMESSAGE_FIELD_NUMBER: builtins.int
        BUMPEXISTINGMESSAGE_FIELD_NUMBER: builtins.int
        NOTEREPLYMESSAGE_FIELD_NUMBER: builtins.int
        RAVENMESSAGEMSGR_FIELD_NUMBER: builtins.int
        NETWORKVERIFICATIONMESSAGE_FIELD_NUMBER: builtins.int
        @property
        def commonSticker(self) -> global___Armadillo.Content.CommonSticker: ...
        @property
        def screenshotAction(self) -> global___Armadillo.Content.ScreenshotAction: ...
        @property
        def extendedContentMessage(self) -> waArmadilloXMA.WAArmadilloXMA_pb2.ExtendedContentMessage: ...
        @property
        def ravenMessage(self) -> global___Armadillo.Content.RavenMessage: ...
        @property
        def ravenActionNotifMessage(self) -> global___Armadillo.Content.RavenActionNotifMessage: ...
        @property
        def extendedMessageContentWithSear(self) -> global___Armadillo.Content.ExtendedContentMessageWithSear: ...
        @property
        def imageGalleryMessage(self) -> global___Armadillo.Content.ImageGalleryMessage: ...
        @property
        def paymentsTransactionMessage(self) -> global___Armadillo.Content.PaymentsTransactionMessage: ...
        @property
        def bumpExistingMessage(self) -> global___Armadillo.Content.BumpExistingMessage: ...
        @property
        def noteReplyMessage(self) -> global___Armadillo.Content.NoteReplyMessage: ...
        @property
        def ravenMessageMsgr(self) -> global___Armadillo.Content.RavenMessage: ...
        @property
        def networkVerificationMessage(self) -> global___Armadillo.Content.NetworkVerificationMessage: ...
        def __init__(
            self,
            *,
            commonSticker: global___Armadillo.Content.CommonSticker | None = ...,
            screenshotAction: global___Armadillo.Content.ScreenshotAction | None = ...,
            extendedContentMessage: waArmadilloXMA.WAArmadilloXMA_pb2.ExtendedContentMessage | None = ...,
            ravenMessage: global___Armadillo.Content.RavenMessage | None = ...,
            ravenActionNotifMessage: global___Armadillo.Content.RavenActionNotifMessage | None = ...,
            extendedMessageContentWithSear: global___Armadillo.Content.ExtendedContentMessageWithSear | None = ...,
            imageGalleryMessage: global___Armadillo.Content.ImageGalleryMessage | None = ...,
            paymentsTransactionMessage: global___Armadillo.Content.PaymentsTransactionMessage | None = ...,
            bumpExistingMessage: global___Armadillo.Content.BumpExistingMessage | None = ...,
            noteReplyMessage: global___Armadillo.Content.NoteReplyMessage | None = ...,
            ravenMessageMsgr: global___Armadillo.Content.RavenMessage | None = ...,
            networkVerificationMessage: global___Armadillo.Content.NetworkVerificationMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["bumpExistingMessage", b"bumpExistingMessage", "commonSticker", b"commonSticker", "content", b"content", "extendedContentMessage", b"extendedContentMessage", "extendedMessageContentWithSear", b"extendedMessageContentWithSear", "imageGalleryMessage", b"imageGalleryMessage", "networkVerificationMessage", b"networkVerificationMessage", "noteReplyMessage", b"noteReplyMessage", "paymentsTransactionMessage", b"paymentsTransactionMessage", "ravenActionNotifMessage", b"ravenActionNotifMessage", "ravenMessage", b"ravenMessage", "ravenMessageMsgr", b"ravenMessageMsgr", "screenshotAction", b"screenshotAction"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["bumpExistingMessage", b"bumpExistingMessage", "commonSticker", b"commonSticker", "content", b"content", "extendedContentMessage", b"extendedContentMessage", "extendedMessageContentWithSear", b"extendedMessageContentWithSear", "imageGalleryMessage", b"imageGalleryMessage", "networkVerificationMessage", b"networkVerificationMessage", "noteReplyMessage", b"noteReplyMessage", "paymentsTransactionMessage", b"paymentsTransactionMessage", "ravenActionNotifMessage", b"ravenActionNotifMessage", "ravenMessage", b"ravenMessage", "ravenMessageMsgr", b"ravenMessageMsgr", "screenshotAction", b"screenshotAction"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["content", b"content"]) -> typing.Literal["commonSticker", "screenshotAction", "extendedContentMessage", "ravenMessage", "ravenActionNotifMessage", "extendedMessageContentWithSear", "imageGalleryMessage", "paymentsTransactionMessage", "bumpExistingMessage", "noteReplyMessage", "ravenMessageMsgr", "networkVerificationMessage"] | None: ...

    PAYLOAD_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def payload(self) -> global___Armadillo.Payload: ...
    @property
    def metadata(self) -> global___Armadillo.Metadata: ...
    def __init__(
        self,
        *,
        payload: global___Armadillo.Payload | None = ...,
        metadata: global___Armadillo.Metadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["metadata", b"metadata", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["metadata", b"metadata", "payload", b"payload"]) -> None: ...

global___Armadillo = Armadillo
