# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waVnameCert/WAWebProtobufsVnameCert.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waVnameCert/WAWebProtobufsVnameCert.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)waVnameCert/WAWebProtobufsVnameCert.proto\x12\x17WAWebProtobufsVnameCert\"\xd0\x02\n\x12\x42izAccountLinkInfo\x12\x1b\n\x13whatsappBizAcctFbid\x18\x01 \x01(\x04\x12\x1a\n\x12whatsappAcctNumber\x18\x02 \x01(\t\x12\x11\n\tissueTime\x18\x03 \x01(\x04\x12P\n\x0bhostStorage\x18\x04 \x01(\x0e\x32;.WAWebProtobufsVnameCert.BizAccountLinkInfo.HostStorageType\x12L\n\x0b\x61\x63\x63ountType\x18\x05 \x01(\x0e\x32\x37.WAWebProtobufsVnameCert.BizAccountLinkInfo.AccountType\"\x1d\n\x0b\x41\x63\x63ountType\x12\x0e\n\nENTERPRISE\x10\x00\"/\n\x0fHostStorageType\x12\x0e\n\nON_PREMISE\x10\x00\x12\x0c\n\x08\x46\x41\x43\x45\x42OOK\x10\x01\"\xa2\x04\n\x0f\x42izIdentityInfo\x12K\n\x06vlevel\x18\x01 \x01(\x0e\x32;.WAWebProtobufsVnameCert.BizIdentityInfo.VerifiedLevelValue\x12\x43\n\tvnameCert\x18\x02 \x01(\x0b\x32\x30.WAWebProtobufsVnameCert.VerifiedNameCertificate\x12\x0e\n\x06signed\x18\x03 \x01(\x08\x12\x0f\n\x07revoked\x18\x04 \x01(\x08\x12M\n\x0bhostStorage\x18\x05 \x01(\x0e\x32\x38.WAWebProtobufsVnameCert.BizIdentityInfo.HostStorageType\x12O\n\x0c\x61\x63tualActors\x18\x06 \x01(\x0e\x32\x39.WAWebProtobufsVnameCert.BizIdentityInfo.ActualActorsType\x12\x15\n\rprivacyModeTS\x18\x07 \x01(\x04\x12\x17\n\x0f\x66\x65\x61tureControls\x18\x08 \x01(\x04\"%\n\x10\x41\x63tualActorsType\x12\x08\n\x04SELF\x10\x00\x12\x07\n\x03\x42SP\x10\x01\"/\n\x0fHostStorageType\x12\x0e\n\nON_PREMISE\x10\x00\x12\x0c\n\x08\x46\x41\x43\x45\x42OOK\x10\x01\"4\n\x12VerifiedLevelValue\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03LOW\x10\x01\x12\x08\n\x04HIGH\x10\x02\"=\n\rLocalizedName\x12\n\n\x02lg\x18\x01 \x01(\t\x12\n\n\x02lc\x18\x02 \x01(\t\x12\x14\n\x0cverifiedName\x18\x03 \x01(\t\"\xeb\x01\n\x17VerifiedNameCertificate\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12\x17\n\x0fserverSignature\x18\x03 \x01(\x0c\x1a\x92\x01\n\x07\x44\x65tails\x12\x0e\n\x06serial\x18\x01 \x01(\x04\x12\x0e\n\x06issuer\x18\x02 \x01(\t\x12\x14\n\x0cverifiedName\x18\x04 \x01(\t\x12>\n\x0elocalizedNames\x18\x08 \x03(\x0b\x32&.WAWebProtobufsVnameCert.LocalizedName\x12\x11\n\tissueTime\x18\n \x01(\x04\"q\n\x11\x42izAccountPayload\x12\x43\n\tvnameCert\x18\x01 \x01(\x0b\x32\x30.WAWebProtobufsVnameCert.VerifiedNameCertificate\x12\x17\n\x0f\x62izAcctLinkInfo\x18\x02 \x01(\x0c\x42\'Z%go.mau.fi/whatsmeow/proto/waVnameCert')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waVnameCert.WAWebProtobufsVnameCert_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z%go.mau.fi/whatsmeow/proto/waVnameCert'
  _globals['_BIZACCOUNTLINKINFO']._serialized_start=71
  _globals['_BIZACCOUNTLINKINFO']._serialized_end=407
  _globals['_BIZACCOUNTLINKINFO_ACCOUNTTYPE']._serialized_start=329
  _globals['_BIZACCOUNTLINKINFO_ACCOUNTTYPE']._serialized_end=358
  _globals['_BIZACCOUNTLINKINFO_HOSTSTORAGETYPE']._serialized_start=360
  _globals['_BIZACCOUNTLINKINFO_HOSTSTORAGETYPE']._serialized_end=407
  _globals['_BIZIDENTITYINFO']._serialized_start=410
  _globals['_BIZIDENTITYINFO']._serialized_end=956
  _globals['_BIZIDENTITYINFO_ACTUALACTORSTYPE']._serialized_start=816
  _globals['_BIZIDENTITYINFO_ACTUALACTORSTYPE']._serialized_end=853
  _globals['_BIZIDENTITYINFO_HOSTSTORAGETYPE']._serialized_start=360
  _globals['_BIZIDENTITYINFO_HOSTSTORAGETYPE']._serialized_end=407
  _globals['_BIZIDENTITYINFO_VERIFIEDLEVELVALUE']._serialized_start=904
  _globals['_BIZIDENTITYINFO_VERIFIEDLEVELVALUE']._serialized_end=956
  _globals['_LOCALIZEDNAME']._serialized_start=958
  _globals['_LOCALIZEDNAME']._serialized_end=1019
  _globals['_VERIFIEDNAMECERTIFICATE']._serialized_start=1022
  _globals['_VERIFIEDNAMECERTIFICATE']._serialized_end=1257
  _globals['_VERIFIEDNAMECERTIFICATE_DETAILS']._serialized_start=1111
  _globals['_VERIFIEDNAMECERTIFICATE_DETAILS']._serialized_end=1257
  _globals['_BIZACCOUNTPAYLOAD']._serialized_start=1259
  _globals['_BIZACCOUNTPAYLOAD']._serialized_end=1372
# @@protoc_insertion_point(module_scope)
