"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import waArmadilloBackupCommon.WAArmadilloBackupCommon_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class BackupMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Metadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class FrankingMetadata(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            FRANKINGTAG_FIELD_NUMBER: builtins.int
            REPORTINGTAG_FIELD_NUMBER: builtins.int
            frankingTag: builtins.bytes
            reportingTag: builtins.bytes
            def __init__(
                self,
                *,
                frankingTag: builtins.bytes | None = ...,
                reportingTag: builtins.bytes | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["frankingTag", b"frankingTag", "reportingTag", b"reportingTag"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["frankingTag", b"frankingTag", "reportingTag", b"reportingTag"]) -> None: ...

        SENDERID_FIELD_NUMBER: builtins.int
        MESSAGEID_FIELD_NUMBER: builtins.int
        TIMESTAMPMS_FIELD_NUMBER: builtins.int
        FRANKINGMETADATA_FIELD_NUMBER: builtins.int
        PAYLOADVERSION_FIELD_NUMBER: builtins.int
        FUTUREPROOFBEHAVIOR_FIELD_NUMBER: builtins.int
        THREADTYPETAG_FIELD_NUMBER: builtins.int
        senderID: builtins.str
        messageID: builtins.str
        timestampMS: builtins.int
        payloadVersion: builtins.int
        futureProofBehavior: builtins.int
        threadTypeTag: builtins.int
        @property
        def frankingMetadata(self) -> global___BackupMessage.Metadata.FrankingMetadata: ...
        def __init__(
            self,
            *,
            senderID: builtins.str | None = ...,
            messageID: builtins.str | None = ...,
            timestampMS: builtins.int | None = ...,
            frankingMetadata: global___BackupMessage.Metadata.FrankingMetadata | None = ...,
            payloadVersion: builtins.int | None = ...,
            futureProofBehavior: builtins.int | None = ...,
            threadTypeTag: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["frankingMetadata", b"frankingMetadata", "futureProofBehavior", b"futureProofBehavior", "messageID", b"messageID", "payloadVersion", b"payloadVersion", "senderID", b"senderID", "threadTypeTag", b"threadTypeTag", "timestampMS", b"timestampMS"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["frankingMetadata", b"frankingMetadata", "futureProofBehavior", b"futureProofBehavior", "messageID", b"messageID", "payloadVersion", b"payloadVersion", "senderID", b"senderID", "threadTypeTag", b"threadTypeTag", "timestampMS", b"timestampMS"]) -> None: ...

    ENCRYPTEDTRANSPORTMESSAGE_FIELD_NUMBER: builtins.int
    ENCRYPTEDTRANSPORTEVENT_FIELD_NUMBER: builtins.int
    ENCRYPTEDTRANSPORTLOCALLYTRANSFORMEDMESSAGE_FIELD_NUMBER: builtins.int
    MITRANSPORTADMINMESSAGE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    encryptedTransportMessage: builtins.bytes
    @property
    def encryptedTransportEvent(self) -> waArmadilloBackupCommon.WAArmadilloBackupCommon_pb2.Subprotocol: ...
    @property
    def encryptedTransportLocallyTransformedMessage(self) -> waArmadilloBackupCommon.WAArmadilloBackupCommon_pb2.Subprotocol: ...
    @property
    def miTransportAdminMessage(self) -> waArmadilloBackupCommon.WAArmadilloBackupCommon_pb2.Subprotocol: ...
    @property
    def metadata(self) -> global___BackupMessage.Metadata: ...
    def __init__(
        self,
        *,
        encryptedTransportMessage: builtins.bytes | None = ...,
        encryptedTransportEvent: waArmadilloBackupCommon.WAArmadilloBackupCommon_pb2.Subprotocol | None = ...,
        encryptedTransportLocallyTransformedMessage: waArmadilloBackupCommon.WAArmadilloBackupCommon_pb2.Subprotocol | None = ...,
        miTransportAdminMessage: waArmadilloBackupCommon.WAArmadilloBackupCommon_pb2.Subprotocol | None = ...,
        metadata: global___BackupMessage.Metadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["encryptedTransportEvent", b"encryptedTransportEvent", "encryptedTransportLocallyTransformedMessage", b"encryptedTransportLocallyTransformedMessage", "encryptedTransportMessage", b"encryptedTransportMessage", "metadata", b"metadata", "miTransportAdminMessage", b"miTransportAdminMessage", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["encryptedTransportEvent", b"encryptedTransportEvent", "encryptedTransportLocallyTransformedMessage", b"encryptedTransportLocallyTransformedMessage", "encryptedTransportMessage", b"encryptedTransportMessage", "metadata", b"metadata", "miTransportAdminMessage", b"miTransportAdminMessage", "payload", b"payload"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["payload", b"payload"]) -> typing.Literal["encryptedTransportMessage", "encryptedTransportEvent", "encryptedTransportLocallyTransformedMessage", "miTransportAdminMessage"] | None: ...

global___BackupMessage = BackupMessage
