"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class UserPassword(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Transformer:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TransformerEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UserPassword._Transformer.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NONE: UserPassword._Transformer.ValueType  # 0
        PBKDF2_HMAC_SHA512: UserPassword._Transformer.ValueType  # 1
        PBKDF2_HMAC_SHA384: UserPassword._Transformer.ValueType  # 2

    class Transformer(_Transformer, metaclass=_TransformerEnumTypeWrapper): ...
    NONE: UserPassword.Transformer.ValueType  # 0
    PBKDF2_HMAC_SHA512: UserPassword.Transformer.ValueType  # 1
    PBKDF2_HMAC_SHA384: UserPassword.Transformer.ValueType  # 2

    class _Encoding:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EncodingEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UserPassword._Encoding.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UTF8: UserPassword._Encoding.ValueType  # 0
        UTF8_BROKEN: UserPassword._Encoding.ValueType  # 1

    class Encoding(_Encoding, metaclass=_EncodingEnumTypeWrapper): ...
    UTF8: UserPassword.Encoding.ValueType  # 0
    UTF8_BROKEN: UserPassword.Encoding.ValueType  # 1

    @typing.final
    class TransformerArg(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class Value(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            ASBLOB_FIELD_NUMBER: builtins.int
            ASUNSIGNEDINTEGER_FIELD_NUMBER: builtins.int
            asBlob: builtins.bytes
            asUnsignedInteger: builtins.int
            def __init__(
                self,
                *,
                asBlob: builtins.bytes | None = ...,
                asUnsignedInteger: builtins.int | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["asBlob", b"asBlob", "asUnsignedInteger", b"asUnsignedInteger", "value", b"value"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["asBlob", b"asBlob", "asUnsignedInteger", b"asUnsignedInteger", "value", b"value"]) -> None: ...
            def WhichOneof(self, oneof_group: typing.Literal["value", b"value"]) -> typing.Literal["asBlob", "asUnsignedInteger"] | None: ...

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___UserPassword.TransformerArg.Value: ...
        def __init__(
            self,
            *,
            key: builtins.str | None = ...,
            value: global___UserPassword.TransformerArg.Value | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ENCODING_FIELD_NUMBER: builtins.int
    TRANSFORMER_FIELD_NUMBER: builtins.int
    TRANSFORMERARG_FIELD_NUMBER: builtins.int
    TRANSFORMEDDATA_FIELD_NUMBER: builtins.int
    encoding: global___UserPassword.Encoding.ValueType
    transformer: global___UserPassword.Transformer.ValueType
    transformedData: builtins.bytes
    @property
    def transformerArg(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserPassword.TransformerArg]: ...
    def __init__(
        self,
        *,
        encoding: global___UserPassword.Encoding.ValueType | None = ...,
        transformer: global___UserPassword.Transformer.ValueType | None = ...,
        transformerArg: collections.abc.Iterable[global___UserPassword.TransformerArg] | None = ...,
        transformedData: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["encoding", b"encoding", "transformedData", b"transformedData", "transformer", b"transformer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["encoding", b"encoding", "transformedData", b"transformedData", "transformer", b"transformer", "transformerArg", b"transformerArg"]) -> None: ...

global___UserPassword = UserPassword
