# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waArmadilloMiTransportAdminMessage/WAArmadilloMiTransportAdminMessage.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waArmadilloMiTransportAdminMessage/WAArmadilloMiTransportAdminMessage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKwaArmadilloMiTransportAdminMessage/WAArmadilloMiTransportAdminMessage.proto\x12\"WAArmadilloMiTransportAdminMessage\"\xce\x15\n\x17MiTransportAdminMessage\x12h\n\x10\x63hatThemeChanged\x18\x01 \x01(\x0b\x32L.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.ChatThemeChangedH\x00\x12\x66\n\x0fnicknameChanged\x18\x02 \x01(\x0b\x32K.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.NicknameChangedH\x00\x12v\n\x17groupParticipantChanged\x18\x03 \x01(\x0b\x32S.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupParticipantChangedH\x00\x12j\n\x11groupAdminChanged\x18\x04 \x01(\x0b\x32M.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupAdminChangedH\x00\x12h\n\x10groupNameChanged\x18\x05 \x01(\x0b\x32L.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupNameChangedH\x00\x12\x82\x01\n\x1dgroupMembershipAddModeChanged\x18\x06 \x01(\x0b\x32Y.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupMembershipAddModeChangedH\x00\x12\x62\n\rmessagePinned\x18\x07 \x01(\x0b\x32I.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.MessagePinnedH\x00\x12j\n\x11groupImageChanged\x18\x08 \x01(\x0b\x32M.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupImageChangedH\x00\x12p\n\x14quickReactionChanged\x18\t \x01(\x0b\x32P.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.QuickReactionChangedH\x00\x12V\n\x07linkCta\x18\n \x01(\x0b\x32\x43.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.LinkCtaH\x00\x12^\n\x0biconChanged\x18\x0b \x01(\x0b\x32G.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.IconChangedH\x00\x12|\n\x1a\x64isappearingSettingChanged\x18\x0c \x01(\x0b\x32V.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.DisappearingSettingChangedH\x00\x1a\x9d\x01\n\x11GroupImageChanged\x12\x64\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32T.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupImageChanged.Action\"\"\n\x06\x41\x63tion\x12\x0b\n\x07\x43HANGED\x10\x01\x12\x0b\n\x07REMOVED\x10\x02\x1a\x95\x01\n\rMessagePinned\x12`\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32P.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.MessagePinned.Action\"\"\n\x06\x41\x63tion\x12\n\n\x06PINNED\x10\x01\x12\x0c\n\x08UNPINNED\x10\x02\x1a\xb7\x01\n\x1dGroupMembershipAddModeChanged\x12l\n\x04mode\x18\x01 \x01(\x0e\x32^.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupMembershipAddModeChanged.Mode\"(\n\x04Mode\x12\x0f\n\x0b\x41LL_MEMBERS\x10\x01\x12\x0f\n\x0b\x41\x44MINS_ONLY\x10\x02\x1a\xb1\x01\n\x11GroupAdminChanged\x12\x14\n\x0ctargetUserID\x18\x01 \x03(\t\x12\x64\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32T.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupAdminChanged.Action\" \n\x06\x41\x63tion\x12\t\n\x05\x41\x44\x44\x45\x44\x10\x01\x12\x0b\n\x07REMOVED\x10\x02\x1a\xbd\x01\n\x17GroupParticipantChanged\x12\x14\n\x0ctargetUserID\x18\x01 \x03(\t\x12j\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32Z.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupParticipantChanged.Action\" \n\x06\x41\x63tion\x12\t\n\x05\x41\x44\x44\x45\x44\x10\x01\x12\x0b\n\x07REMOVED\x10\x02\x1aw\n\x1a\x44isappearingSettingChanged\x12*\n\"disappearingSettingDurationSeconds\x18\x01 \x01(\x05\x12-\n%oldDisappearingSettingDurationSeconds\x18\x02 \x01(\x05\x1a!\n\x0bIconChanged\x12\x12\n\nthreadIcon\x18\x01 \x01(\t\x1a\xad\x01\n\x07LinkCta\x12l\n\x0eukOsaAdminText\x18\x01 \x01(\x0b\x32R.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.LinkCta.UkOsaAdminTextH\x00\x1a)\n\x0eUkOsaAdminText\x12\x17\n\x0finitiatorUserID\x18\x02 \x01(\tB\t\n\x07\x63ontent\x1a)\n\x14QuickReactionChanged\x12\x11\n\temojiName\x18\x01 \x01(\t\x1a%\n\x10GroupNameChanged\x12\x11\n\tgroupName\x18\x01 \x01(\t\x1a\x39\n\x0fNicknameChanged\x12\x14\n\x0ctargetUserID\x18\x01 \x01(\t\x12\x10\n\x08nickname\x18\x02 \x01(\t\x1aL\n\x10\x43hatThemeChanged\x12\x11\n\tthemeName\x18\x01 \x01(\t\x12\x12\n\nthemeEmoji\x18\x02 \x01(\t\x12\x11\n\tthemeType\x18\x03 \x01(\x05\x42\t\n\x07\x63ontentB>Z<go.mau.fi/whatsmeow/proto/waArmadilloMiTransportAdminMessage')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waArmadilloMiTransportAdminMessage.WAArmadilloMiTransportAdminMessage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<go.mau.fi/whatsmeow/proto/waArmadilloMiTransportAdminMessage'
  _globals['_MITRANSPORTADMINMESSAGE']._serialized_start=116
  _globals['_MITRANSPORTADMINMESSAGE']._serialized_end=2882
  _globals['_MITRANSPORTADMINMESSAGE_GROUPIMAGECHANGED']._serialized_start=1453
  _globals['_MITRANSPORTADMINMESSAGE_GROUPIMAGECHANGED']._serialized_end=1610
  _globals['_MITRANSPORTADMINMESSAGE_GROUPIMAGECHANGED_ACTION']._serialized_start=1576
  _globals['_MITRANSPORTADMINMESSAGE_GROUPIMAGECHANGED_ACTION']._serialized_end=1610
  _globals['_MITRANSPORTADMINMESSAGE_MESSAGEPINNED']._serialized_start=1613
  _globals['_MITRANSPORTADMINMESSAGE_MESSAGEPINNED']._serialized_end=1762
  _globals['_MITRANSPORTADMINMESSAGE_MESSAGEPINNED_ACTION']._serialized_start=1728
  _globals['_MITRANSPORTADMINMESSAGE_MESSAGEPINNED_ACTION']._serialized_end=1762
  _globals['_MITRANSPORTADMINMESSAGE_GROUPMEMBERSHIPADDMODECHANGED']._serialized_start=1765
  _globals['_MITRANSPORTADMINMESSAGE_GROUPMEMBERSHIPADDMODECHANGED']._serialized_end=1948
  _globals['_MITRANSPORTADMINMESSAGE_GROUPMEMBERSHIPADDMODECHANGED_MODE']._serialized_start=1908
  _globals['_MITRANSPORTADMINMESSAGE_GROUPMEMBERSHIPADDMODECHANGED_MODE']._serialized_end=1948
  _globals['_MITRANSPORTADMINMESSAGE_GROUPADMINCHANGED']._serialized_start=1951
  _globals['_MITRANSPORTADMINMESSAGE_GROUPADMINCHANGED']._serialized_end=2128
  _globals['_MITRANSPORTADMINMESSAGE_GROUPADMINCHANGED_ACTION']._serialized_start=2096
  _globals['_MITRANSPORTADMINMESSAGE_GROUPADMINCHANGED_ACTION']._serialized_end=2128
  _globals['_MITRANSPORTADMINMESSAGE_GROUPPARTICIPANTCHANGED']._serialized_start=2131
  _globals['_MITRANSPORTADMINMESSAGE_GROUPPARTICIPANTCHANGED']._serialized_end=2320
  _globals['_MITRANSPORTADMINMESSAGE_GROUPPARTICIPANTCHANGED_ACTION']._serialized_start=2096
  _globals['_MITRANSPORTADMINMESSAGE_GROUPPARTICIPANTCHANGED_ACTION']._serialized_end=2128
  _globals['_MITRANSPORTADMINMESSAGE_DISAPPEARINGSETTINGCHANGED']._serialized_start=2322
  _globals['_MITRANSPORTADMINMESSAGE_DISAPPEARINGSETTINGCHANGED']._serialized_end=2441
  _globals['_MITRANSPORTADMINMESSAGE_ICONCHANGED']._serialized_start=2443
  _globals['_MITRANSPORTADMINMESSAGE_ICONCHANGED']._serialized_end=2476
  _globals['_MITRANSPORTADMINMESSAGE_LINKCTA']._serialized_start=2479
  _globals['_MITRANSPORTADMINMESSAGE_LINKCTA']._serialized_end=2652
  _globals['_MITRANSPORTADMINMESSAGE_LINKCTA_UKOSAADMINTEXT']._serialized_start=2600
  _globals['_MITRANSPORTADMINMESSAGE_LINKCTA_UKOSAADMINTEXT']._serialized_end=2641
  _globals['_MITRANSPORTADMINMESSAGE_QUICKREACTIONCHANGED']._serialized_start=2654
  _globals['_MITRANSPORTADMINMESSAGE_QUICKREACTIONCHANGED']._serialized_end=2695
  _globals['_MITRANSPORTADMINMESSAGE_GROUPNAMECHANGED']._serialized_start=2697
  _globals['_MITRANSPORTADMINMESSAGE_GROUPNAMECHANGED']._serialized_end=2734
  _globals['_MITRANSPORTADMINMESSAGE_NICKNAMECHANGED']._serialized_start=2736
  _globals['_MITRANSPORTADMINMESSAGE_NICKNAMECHANGED']._serialized_end=2793
  _globals['_MITRANSPORTADMINMESSAGE_CHATTHEMECHANGED']._serialized_start=2795
  _globals['_MITRANSPORTADMINMESSAGE_CHATTHEMECHANGED']._serialized_end=2871
# @@protoc_insertion_point(module_scope)
