"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RoutingInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGIONID_FIELD_NUMBER: builtins.int
    CLUSTERID_FIELD_NUMBER: builtins.int
    TASKID_FIELD_NUMBER: builtins.int
    DEBUG_FIELD_NUMBER: builtins.int
    TCPBBR_FIELD_NUMBER: builtins.int
    TCPKEEPALIVE_FIELD_NUMBER: builtins.int
    taskID: builtins.int
    debug: builtins.bool
    tcpBbr: builtins.bool
    tcpKeepalive: builtins.bool
    @property
    def regionID(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def clusterID(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        regionID: collections.abc.Iterable[builtins.int] | None = ...,
        clusterID: collections.abc.Iterable[builtins.int] | None = ...,
        taskID: builtins.int | None = ...,
        debug: builtins.bool | None = ...,
        tcpBbr: builtins.bool | None = ...,
        tcpKeepalive: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["debug", b"debug", "taskID", b"taskID", "tcpBbr", b"tcpBbr", "tcpKeepalive", b"tcpKeepalive"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["clusterID", b"clusterID", "debug", b"debug", "regionID", b"regionID", "taskID", b"taskID", "tcpBbr", b"tcpBbr", "tcpKeepalive", b"tcpKeepalive"]) -> None: ...

global___RoutingInfo = RoutingInfo
