# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waWinUIApi/WAWinUIApi.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waWinUIApi/WAWinUIApi.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bwaWinUIApi/WAWinUIApi.proto\x12\nWAWinUIApi\"\xa7\x02\n\x0fPositronMessage\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12.\n\x02ID\x18\x04 \x01(\x0b\x32\".WAWinUIApi.PositronMessage.MsgKey\x12\x0c\n\x04JSON\x18\x63 \x01(\t\x1a\x8b\x01\n\x06MsgKey\x12\x0e\n\x06\x66romMe\x18\x01 \x01(\x08\x12/\n\x06remote\x18\x02 \x01(\x0b\x32\x1f.WAWinUIApi.PositronMessage.WID\x12\n\n\x02ID\x18\x03 \x01(\t\x12\x34\n\x0bparticipant\x18\x04 \x01(\x0b\x32\x1f.WAWinUIApi.PositronMessage.WID\x1a\x19\n\x03WID\x12\x12\n\nserialized\x18\x01 \x01(\t\"^\n\x0cPositronChat\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x12\x13\n\x0bunreadCount\x18\x04 \x01(\x03\x12\x0c\n\x04JSON\x18\x63 \x01(\t\"l\n\x0fPositronContact\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x13\n\x0bphoneNumber\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1c\n\x14isAddressBookContact\x18\x04 \x01(\x08\x12\x0c\n\x04JSON\x18\x63 \x01(\t\"B\n\x15PositronGroupMetadata\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x0c\n\x04JSON\x18\x63 \x01(\t\"K\n\x19PositronGroupParticipants\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x14\n\x0cparticipants\x18\x02 \x03(\t\x12\x0c\n\x04JSON\x18\x63 \x01(\t\"\x82\x01\n\x10PositronReaction\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x14\n\x0cparentMsgKey\x18\x02 \x01(\t\x12\x14\n\x0creactionText\x18\x03 \x01(\t\x12\x11\n\ttimestamp\x18\x04 \x01(\x03\x12\x15\n\rsenderUserJID\x18\x05 \x01(\t\x12\x0c\n\x04JSON\x18\x63 \x01(\t\"\xf6\x02\n\x0cPositronData\x12\x32\n\ndataSource\x18\x01 \x01(\x0e\x32\x1e.WAWinUIApi.PositronDataSource\x12-\n\x08messages\x18\x02 \x03(\x0b\x32\x1b.WAWinUIApi.PositronMessage\x12\'\n\x05\x63hats\x18\x03 \x03(\x0b\x32\x18.WAWinUIApi.PositronChat\x12-\n\x08\x63ontacts\x18\x04 \x03(\x0b\x32\x1b.WAWinUIApi.PositronContact\x12\x38\n\rgroupMetadata\x18\x05 \x03(\x0b\x32!.WAWinUIApi.PositronGroupMetadata\x12@\n\x11groupParticipants\x18\x06 \x03(\x0b\x32%.WAWinUIApi.PositronGroupParticipants\x12/\n\treactions\x18\x07 \x03(\x0b\x32\x1c.WAWinUIApi.PositronReaction*v\n\x12PositronDataSource\x12\x0c\n\x08MESSAGES\x10\x01\x12\t\n\x05\x43HATS\x10\x02\x12\x0c\n\x08\x43ONTACTS\x10\x03\x12\x12\n\x0eGROUP_METADATA\x10\x04\x12\x16\n\x12GROUP_PARTICIPANTS\x10\x05\x12\r\n\tREACTIONS\x10\x06\x42&Z$go.mau.fi/whatsmeow/proto/waWinUIApi')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waWinUIApi.WAWinUIApi_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z$go.mau.fi/whatsmeow/proto/waWinUIApi'
  _globals['_POSITRONDATASOURCE']._serialized_start=1202
  _globals['_POSITRONDATASOURCE']._serialized_end=1320
  _globals['_POSITRONMESSAGE']._serialized_start=44
  _globals['_POSITRONMESSAGE']._serialized_end=339
  _globals['_POSITRONMESSAGE_MSGKEY']._serialized_start=173
  _globals['_POSITRONMESSAGE_MSGKEY']._serialized_end=312
  _globals['_POSITRONMESSAGE_WID']._serialized_start=314
  _globals['_POSITRONMESSAGE_WID']._serialized_end=339
  _globals['_POSITRONCHAT']._serialized_start=341
  _globals['_POSITRONCHAT']._serialized_end=435
  _globals['_POSITRONCONTACT']._serialized_start=437
  _globals['_POSITRONCONTACT']._serialized_end=545
  _globals['_POSITRONGROUPMETADATA']._serialized_start=547
  _globals['_POSITRONGROUPMETADATA']._serialized_end=613
  _globals['_POSITRONGROUPPARTICIPANTS']._serialized_start=615
  _globals['_POSITRONGROUPPARTICIPANTS']._serialized_end=690
  _globals['_POSITRONREACTION']._serialized_start=693
  _globals['_POSITRONREACTION']._serialized_end=823
  _globals['_POSITRONDATA']._serialized_start=826
  _globals['_POSITRONDATA']._serialized_end=1200
# @@protoc_insertion_point(module_scope)
