# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waFingerprint/WAFingerprint.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waFingerprint/WAFingerprint.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!waFingerprint/WAFingerprint.proto\x12\rWAFingerprint\"\xb7\x01\n\x0f\x46ingerprintData\x12\x11\n\tpublicKey\x18\x01 \x01(\x0c\x12\x14\n\x0cpnIdentifier\x18\x02 \x01(\x0c\x12\x15\n\rlidIdentifier\x18\x03 \x01(\x0c\x12\x1a\n\x12usernameIdentifier\x18\x04 \x01(\x0c\x12/\n\x0bhostedState\x18\x05 \x01(\x0e\x32\x1a.WAFingerprint.HostedState\x12\x17\n\x0fhashedPublicKey\x18\x06 \x01(\x0c\"\x9b\x01\n\x13\x43ombinedFingerprint\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x38\n\x10localFingerprint\x18\x02 \x01(\x0b\x32\x1e.WAFingerprint.FingerprintData\x12\x39\n\x11remoteFingerprint\x18\x03 \x01(\x0b\x32\x1e.WAFingerprint.FingerprintData*#\n\x0bHostedState\x12\x08\n\x04\x45\x32\x45\x45\x10\x00\x12\n\n\x06HOSTED\x10\x01\x42)Z\'go.mau.fi/whatsmeow/proto/waFingerprint')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waFingerprint.WAFingerprint_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\'go.mau.fi/whatsmeow/proto/waFingerprint'
  _globals['_HOSTEDSTATE']._serialized_start=396
  _globals['_HOSTEDSTATE']._serialized_end=431
  _globals['_FINGERPRINTDATA']._serialized_start=53
  _globals['_FINGERPRINTDATA']._serialized_end=236
  _globals['_COMBINEDFINGERPRINT']._serialized_start=239
  _globals['_COMBINEDFINGERPRINT']._serialized_end=394
# @@protoc_insertion_point(module_scope)
